#
# spec file for package java-1_8_0-ibm
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#
# nodebuginfo


# Standard JPackage naming and versioning defines.
# Remember to sync baselibs.conf when adjusting!
%define priority        1800
%define javaver         1.8.0
%define buildver        8.15
%define top_leveldir    ibm-java-%{_arch}-80
# Standard JPackage directories and symbolic links.
%define sdklnk          java-%{javaver}-ibm
%define jrelnk          jre-%{javaver}-ibm
%define sdkcompatdir    %{name}-%{javaver}
%define sdkdir          %{sdklnk}-%{javaver}
%define jredir          %{sdkdir}/jre
%define sdkbindir       %{_jvmdir}/%{sdklnk}/bin
%define jrebindir       %{_jvmdir}/%{jrelnk}/bin
%define jrelibdir       %{_jvmdir}/%{jrelnk}/lib
%define jvmjardir       %{_jvmjardir}/%{sdkdir}
%define jvmjarlink      %{_jvmjardir}/%{sdklnk}
# definitions for plugins
%define archinstall %{_arch}
%define plugin_arches %ix86 x86_64
%define pluginpath      %{_jvmdir}/%{jredir}/lib/%{archinstall}/
%define pluginname      libnpjp2.so
# Avoid RPM 4.2+'s internal dep generator, it may produce bogus
# Provides/Requires here.
%define _use_internal_dependency_generator 0
%define    __find_provides %{SOURCE1004}
%define    __find_requires %{SOURCE1005}
# Disable debug generator
%define __debug_install_post %{nil}
%define debug_package %{nil}
%define suse_insert_debug_package %{nil}
%define _suse_insert_debug_package %{nil}
%define _suse_insert_debug_package_seen %{nil}
%ifarch %ix86
%define archinstall i386
%endif
%ifarch x86_64
%define archinstall amd64
%endif
# 32-bit versus 64-bit specific provides:
%ifarch %ix86 ppc s390
%define bits 32
%endif
%ifarch x86_64 ppc64 ppc64le ia64 s390x
%define bits 64
%endif
Name:           java-1_8_0-ibm
Version:        %{javaver}_sr%{buildver}
Release:        150000.3.83.1
Summary:        IBM Java(TM) Version 8 Runtime Environment
License:        SUSE-NonFree
Group:          Development/Languages/Java
Url:            http://www.ibm.com/developerworks/java/jdk/
Source0:        ibm-java-sdk-8.0-%{buildver}-i386-archive.bin
Source2:        ibm-java-sdk-8.0-%{buildver}-ppc64le-archive.bin
Source3:        ibm-java-sdk-8.0-%{buildver}-s390-archive.bin
Source4:        ibm-java-sdk-8.0-%{buildver}-s390x-archive.bin
Source5:        ibm-java-sdk-8.0-%{buildver}-x86_64-archive.bin
Source6:        ibm-java-sdk-8.0-%{buildver}-ppc64-archive.bin
Source7:        ibm-java-sdk-8.0-%{buildver}-ppc-archive.bin
Source1000:     baselibs.conf
Source1001:     font.properties.SUSE.tar.bz2
Source1002:     java-1_8_0-ibm-rpmlintrc
Source1003:     qa_filelists.tar.bz2
Source1004:     filter-provides.sh
Source1005:     filter-requires.sh
NoSource:       0
NoSource:       2
NoSource:       3
NoSource:       4
NoSource:       5
NoSource:       6
NoSource:       7
BuildRequires:  timezone
BuildRequires:  unzip
BuildRequires:  update-alternatives
BuildRequires:  update-desktop-files
Requires(pre):  coreutils
Requires(post): update-alternatives
Requires(postun): update-alternatives
# Standard JPackage base provides.
Provides:       java = %{javaver}
Provides:       java-%{javaver} = %{version}-%{release}
Provides:       java-%{javaver}-ibm = %{version}-%{release}
Provides:       java-ibm = %{version}-%{release}
Provides:       jre = %{javaver}
Provides:       jre-%{javaver} = %{version}-%{release}
Provides:       jre-%{javaver}-ibm = %{version}-%{release}
Provides:       jre-ibm = %{version}-%{release}
# Standard JPackage extensions provides.
Provides:       jaas = %{javaver}
Provides:       java-sasl = %{javaver}
Provides:       jce = %{javaver}
Provides:       jdbc-stdext = %{javaver}
Provides:       jndi = %{javaver}
Provides:       jndi-cos = %{javaver}
Provides:       jndi-dns = %{javaver}
Provides:       jndi-ldap = %{javaver}
Provides:       jndi-rmi = %{javaver}
Provides:       jsse = %{javaver}
# Required at least by fop
Provides:       jre1.3.x
Provides:       jre1.4.x
Provides:       jre1.5.x
Provides:       jre1.6.x
Provides:       jre1.7.x
Provides:       java-%{bits} = %{javaver}
Provides:       java-%{javaver}-%{bits}
Provides:       java-ibm-%{bits} = %{version}-%{release}
Provides:       jdbc-stdext-%{bits}
Provides:       jndi-%{bits}
Provides:       jre-%{bits} = %{javaver}
Provides:       jre-%{javaver}-%{bits}
Provides:       jre-%{javaver}-ibm-%{bits} = %{version}-%{release}
Provides:       jre-ibm-%{bits} = %{version}-%{release}
# older packages provided -fonts in a subpackage
Provides:       %{name}-fonts = %{version}-%{release}
Obsoletes:      %{name}-fonts < %{version}-%{release}
Provides:       java-%{javaver}-fonts
Provides:       java-fonts = %{javaver}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
ExclusiveArch:  %ix86 ppc ppc64 ppc64le s390 s390x x86_64
%if 0%{?suse_version} > 1100
BuildRequires:  fdupes
%endif
%if 0%{?suse_version} > 1210
BuildRequires:  ca-certificates
Requires:       ca-certificates
BuildRequires:  javapackages-tools
Requires:       javapackages-tools
%else
BuildRequires:  jpackage-utils
Requires:       jpackage-utils >= 1.5.38
%endif
# install script expects /lib/libc.so.6 installed
%ifarch x86_64 ppc64 s390x
BuildRequires:  glibc-32bit
%endif

%description
Java(TM) Version 8 Runtime Environment

The Java(TM) Version 8 Runtime Environment contains the Java virtual
machine, runtime class libraries, and Java application launcher that are
necessary to run programs written in the Java progamming language. It is not a
development environment and does not contain development tools such as
compilers and debuggers. For development tools, see the
%{name}-devel package.

The Java Version 8 Runtime Environment is intended for software
developers and vendors who wish to redistribute their applications.

%package        devel
Summary:        IBM Java(TM) Version 8 SDK, Standard Edition
Group:          Development/Languages/Java
Requires:       %{name} = %{version}-%{release}
Requires(post): %{name} = %{version}-%{release}
Requires(post): update-alternatives
Provides:       java-%{javaver}-ibm-devel = %{version}-%{release}
Provides:       java-%{javaver}-devel = %{version}
Provides:       java-devel = %{javaver}
Provides:       java-devel-ibm = %{version}
Provides:       java-sdk = %{javaver}
Provides:       java-sdk-%{javaver} = %{version}
Provides:       java-sdk-%{javaver}-ibm = %{version}
Provides:       java-sdk-ibm = %{version}

%description    devel
The Java Version 8 SDK is a development environment for building
applications, applets, and components using the Java programming language.

The Java Version 8 SDK includes tools useful for developing and
testing programs written in the Java programming language and running on the
Java platform. These tools are designed to be used from the command line.
Except for the appletviewer, these tools do not provide a graphical user
interface.

%package        src
Summary:        IBM Java(TM) Version 8 sources
Group:          Development/Languages/Java
Requires:       %{name} = %{version}

%description    src
Java(TM) Version 8 Runtime Environment

The Java(TM) Version 8 Runtime Environment contains the Java virtual
machine, runtime class libraries, and Java application launcher that are
necessary to run programs written in the Java progamming language. It is not a
development environment and does not contain development tools such as
compilers and debuggers. For development tools, see the
%{name}-devel package.

The Java Version 8 Runtime Environment is intended for software
developers and vendors who wish to redistribute their applications.

%package        demo
Summary:        Demonstration files for %{name}
Group:          Development/Languages/Java
Requires:       %{name} = %{version}
# Without this a requirement on libjava_crw_demo_g.so is added which
# is not in the main java package. libjava_crw_demo.so is but not "_g".
AutoReq:        0

%description    demo
This package contains demonstration files for %{name}.

%ifarch %{plugin_arches}
%package        plugin
Summary:        Browser plugin files for %{name}
Group:          Development/Languages/Java
Requires:       %{name} = %{version}
Requires(post): %{name} = %{version}
Requires(post): update-alternatives
Provides:       java-%{javaver}-plugin = %{version}
Provides:       java-plugin = %{javaver}
Obsoletes:      java-1.3.1-plugin < %{javaver}
Obsoletes:      java-1.4.0-plugin < %{javaver}
Obsoletes:      java-1.4.1-plugin < %{javaver}
Obsoletes:      java-1.4.2-plugin < %{javaver}
Provides:       java-1.3.1-plugin = %{javaver}
Provides:       java-1.4.0-plugin = %{javaver}
Provides:       java-1.4.1-plugin = %{javaver}
Provides:       java-1.4.2-plugin = %{javaver}
Provides:       javaws = %{javaver}

%description    plugin
This package contains browser plugin files for %{name}. Note:
this package supports browsers built with GCC 3.2 and later
%endif

%ifarch %ix86 x86_64
%package        alsa
Summary:        ALSA support for %{name}
Group:          Development/Languages/Java
Requires:       %{name} = %{version}

%description    alsa
This package contains Advanced Linux Sound Architecture (ALSA) support
libraries for %{name}.
%endif

%prep
%setup -q -T -c

export LC_ALL=en_US.UTF-8
export TZ=UTC
cat > installer.properties <<EOF
INSTALLER_UI=silent
USER_INSTALL_DIR=%{_sourcedir}/%{top_leveldir}
LICENSE_ACCEPTED=TRUE
EOF

%ifarch %ix86
%define ARCHIVE %{SOURCE0}
%endif

%ifarch ppc64
%define ARCHIVE %{SOURCE6}
%endif

%ifarch ppc
%define ARCHIVE %{SOURCE7}
%endif

%ifarch ppc64le
%define ARCHIVE %{SOURCE2}
%endif

%ifarch s390
%define ARCHIVE %{SOURCE3}
%endif

%ifarch s390x
%define ARCHIVE %{SOURCE4}
%endif

%ifarch x86_64
%define ARCHIVE %{SOURCE5}
%endif

sh %{ARCHIVE} -i silent -f `pwd`/installer.properties || :

if [ ! -d %{top_leveldir} -a -d %{_sourcedir}/%{top_leveldir} ]; then
    mv %{_sourcedir}/%{top_leveldir}/* .
else
    echo "Cannot find %{top_leveldir}, unpacking have failed"
    exit 42
fi

# unpack font properties
%setup -q -T -D -a 1001
#qa_filelists
%setup -q -T -D -a 1003

find . -type f -iname '*.exe' -o -iname '*.bat' -o -iname '*.desktop' -exec rm {} + ||:

# remove splash screen, which are binaries compiled for various architectures
rm -rf docs/launchpad/splash
chmod -R go=u-w *
chmod -R u+w *
chmod 644 copyright release src.zip
find docs demo -type f | xargs chmod 644
find . -name '*.txt' -or -name '*.c' -or -name '*.h' -or -name '*.cpp' -or -name '*.zip' | xargs chmod 0644

# Fix the perms on requires/provides filters
chmod +x %{SOURCE1004}
chmod +x %{SOURCE1005}

%build
# Nope.

%install
# Do not modify binaries
export NO_DEBUGINFO_STRIP_DEBUG=true
export NO_BRP_CHECK_BYTECODE_VERSION="true"
export NO_BRP_CHECK_RPATH="true"
export NO_BRP_STRIP_DEBUG="true"

# Install main files.
install -d -m 755 %{buildroot}%{_jvmdir}/%{sdkdir}
cp -a bin include lib src.zip %{buildroot}%{_jvmdir}/%{sdkdir}
(cd %{buildroot}%{_jvmdir}/%{sdkdir} && ln -s src.zip src.jar)

install -d -m 755 %{buildroot}%{_jvmdir}/%{jredir}
install -d -m 755 %{buildroot}%{_jvmdir}/%{jredir}/lib/endorsed
cp -a jre/bin jre/lib %{buildroot}%{_jvmdir}/%{jredir}

# on ppc64, there're two files in tarball, so let's copy that as well
%ifarch %{plugin_arches} ppc64
    cp -a jre/plugin %{buildroot}%{_jvmdir}/%{jredir}
%endif

# on some archs, there are two additional FIPS directories and cacerts
%ifarch ppc64le ppc64 s390x x86_64
    cp -a jre/fips140-{2,3} %{buildroot}%{_jvmdir}/%{jredir}
    # FIPS security cacert from system
    rm -rf  %{buildroot}%{_jvmdir}/%{sdkdir}/jre/fips140-3/lib/security/cacerts
    ln -s %{_localstatedir}/lib/ca-certificates/java-cacerts %{buildroot}%{_jvmdir}/%{sdkdir}/jre/fips140-3/lib/security/cacerts
%endif

# Install extension symlinks.
install -d -m 755 %{buildroot}%{jvmjardir}
pushd %{buildroot}%{jvmjardir}
ln -s %{_jvmdir}/%{jredir}/lib/ibmjsseprovider2.jar jsse-%{version}.jar
ln -s %{_jvmdir}/%{jredir}/lib/ibmjcefw.jar jce-%{version}.jar
ln -s %{_jvmdir}/%{jredir}/lib/rt.jar jndi-%{version}.jar
ln -s %{_jvmdir}/%{jredir}/lib/rt.jar jndi-ldap-%{version}.jar
ln -s %{_jvmdir}/%{jredir}/lib/rt.jar jndi-cos-%{version}.jar
ln -s %{_jvmdir}/%{jredir}/lib/rt.jar jndi-rmi-%{version}.jar
ln -s %{_jvmdir}/%{jredir}/lib/rt.jar jaas-%{version}.jar
ln -s %{_jvmdir}/%{jredir}/lib/rt.jar jdbc-stdext-%{version}.jar
ln -s jdbc-stdext-%{version}.jar jdbc-stdext-3.0.jar
ln -s %{_jvmdir}/%{jredir}/lib/rt.jar sasl-%{version}.jar
for jar in *-%{version}.jar ; do
    if [ x%{version} != x%{javaver} ]; then
        ln -fs ${jar} $(echo $jar | sed "s|-%{version}.jar|-%{javaver}.jar|g")
    fi
    ln -fs ${jar} $(echo $jar | sed "s|-%{version}.jar|.jar|g")
done
popd

# jce policy file handling
install -d -m 755 %{buildroot}%{_jvmprivdir}/%{sdklnk}/jce/vanilla/limited
install -d -m 755 %{buildroot}%{_jvmprivdir}/%{sdklnk}/jce/vanilla/unlimited
for file in local_policy.jar US_export_policy.jar; do
    mv %{buildroot}%{_jvmdir}/%{jredir}/lib/security/policy/limited/$file \
        %{buildroot}%{_jvmprivdir}/%{sdklnk}/jce/vanilla/limited
    mv %{buildroot}%{_jvmdir}/%{jredir}/lib/security/policy/unlimited/$file \
        %{buildroot}%{_jvmprivdir}/%{sdklnk}/jce/vanilla/unlimited
    # for ghosts
    touch %{buildroot}%{_jvmdir}/%{jredir}/lib/security/policy/limited/$file
    touch %{buildroot}%{_jvmdir}/%{jredir}/lib/security/policy/unlimited/$file
done
# Add compat dir for old JCE folder
pushd %{buildroot}%{_jvmprivdir}/
touch %{name}
popd

# Install versionless symlinks.
pushd %{buildroot}%{_jvmdir}
ln -s %{jredir} %{jrelnk}
ln -s %{sdkdir} %{sdklnk}
touch %{sdkcompatdir}
popd
pushd %{buildroot}%{_jvmjardir}
ln -s %{sdkdir} %{jrelnk}
ln -s %{sdkdir} %{sdklnk}
touch %{sdkcompatdir}
popd

# Install freedesktop.org menu entry for console
%ifarch %{plugin_arches}
    #XXX: unzip reports an error when running inside chroot, even if all arguments
    #     are correct - let ignore it and check if javalogo.gif exists
    yes | unzip -q demo/jfc/Metalworks/src.zip \
        demo/jfc/Metalworks/src.zip resources/HelpFiles/javalogo.gif || :

    if [[ ! -f resources/HelpFiles/javalogo.gif ]]; then
        echo "ERROR: unpacking have failed"
        exit 42
    fi

    install -dm 755 %{buildroot}%{_datadir}/applications
    # menu entry for web start (reuse plugin control panel icon)
    install -Dpm 644 resources/HelpFiles/javalogo.gif \
        %{buildroot}%{_datadir}/pixmaps/ibm-java-%{javaver}.png

    # cleanup resources
    rm -rf resources

    cat <<EOF > %{buildroot}%{_datadir}/applications/jpackage-%{name}-ControlPanel.desktop
[Desktop Entry]
Name=IBM Java %{version} Java Plug-in Control Panel
GenericName=Java Plugin Control Panel
Comment=IBM Java %{version} Java Plug-in Control Panel
Exec=%{_jvmdir}/%{jredir}/bin/ControlPanel
Icon=ibm-java-%{javaver}
Terminal=false
Type=Application
EOF
    chmod 644 %{buildroot}%{_datadir}/applications/jpackage-%{name}-ControlPanel.desktop
    %suse_update_desktop_file -r %{buildroot}%{_datadir}/applications/jpackage-%{name}-ControlPanel.desktop Java System Monitor

    cat <<EOF > %{buildroot}%{_datadir}/applications/jpackage-%{name}-webstart.desktop
[Desktop Entry]
Name=IBM  Java %{version} Java Web Start
GenericName=Java Web Start
Comment=Java Web Start Application Manager
Exec=%{_jvmdir}/%{jredir}/bin/javaws
Icon=ibm-java-%{javaver}
Terminal=false
Type=Application
Encoding=UTF-8
Categories=Application;System;Java;X-JPackage;
MimeType=application/x-java-jnlp-file;
EOF
    chmod 644 %{buildroot}%{_datadir}/applications/jpackage-%{name}-webstart.desktop
    %suse_update_desktop_file -r %{buildroot}%{_datadir}/applications/jpackage-%{name}-webstart.desktop Java System Monitor
%endif

# Install demos and samples.
cp -a demo %{buildroot}%{_jvmdir}/%{sdkdir}
# install also samples, if possible
if [[ -d sample ]]; then
    # enable short-circuit
    mkdir -p sample/rmi
    [ -f bin/java-rmi.cgi ] && mv bin/java-rmi.cgi sample/rmi
    cp -a sample %{buildroot}%{_jvmdir}/%{sdkdir}/demo
fi

### font handling
pushd %{buildroot}/%{_jvmdir}/%{jredir}/lib
# Remove font.properties and use the system-wide one
rm -f font.properties
ln -fs %{_sysconfdir}/java/font.properties .
popd

# fdupes links the files from JDK to JRE, so it breaks a JRE
# use it carefully :))
%if 0%{?suse_version} > 1100
%fdupes -s %{buildroot}/%{_jvmdir}/%{jredir}/
%fdupes -s %{buildroot}/%{_jvmdir}/%{sdkdir}/demo
%fdupes -s %{buildroot}%{_javadocdir}/%{sdklnk}
%endif
# bnc#394974
install -d -m 0755 %{buildroot}/%{_jvmdir}/%{jredir}/.systemPrefs

# security cacert from system
%if 0%{?suse_version} > 1210
    rm -rf  %{buildroot}%{_jvmdir}/%{jredir}/lib/security/cacerts
    ln -s %{_localstatedir}/lib/ca-certificates/java-cacerts %{buildroot}%{_jvmdir}/%{jredir}/lib/security/cacerts
%endif

# qa filelists
%ifarch %ix86
    install qa_filelists/filelist.i586 %{buildroot}/%{_jvmdir}/%{jredir}/.qa_filelist.%{_arch}
%else
    install qa_filelists/filelist.%{_arch} %{buildroot}/%{_jvmdir}/%{jredir}/.qa_filelist.%{_arch}
%endif

# HACK FOR DISABLED DEBUG
echo "%{_libexecdir}/debug" > debugfiles.list
mkdir -p %{buildroot}%{_libexecdir}/debug
echo "%{_prefix}/src/debug" > debugsources.list
mkdir -p %{buildroot}%{_prefix}/src/debug

# Fix a javaws broken link bsc#1195146
%ifnarch s390 s390x
rm %{buildroot}%{_jvmdir}/%{sdkdir}/jre/bin/javaws
cp %{buildroot}%{_jvmdir}/%{sdkdir}/{,jre/}bin/javaws
%endif

%pre
# previous versions of the package installed in some cases sdkdir and jredir bit differently
# make sure we don't leave out any leftovers and allow symlink backcompat
if [ -d %{_jvmdir}/%{sdkcompatdir} -a ! -L %{_jvmdir}/%{sdkcompatdir} ]; then
  rm -rf %{_jvmdir}/%{sdkcompatdir}
fi
if [ -d %{_jvmjardir}/%{sdkcompatdir} -a ! -L %{_jvmjardir}/%{sdkcompatdir} ]; then
  rm -rf %{_jvmjardir}/%{sdkcompatdir}
fi
if [ -d %{_jvmprivdir}/%{name} -a ! -L %{_jvmprivdir}/%{name} ]; then
  rm -rf %{_jvmprivdir}/%{name}
fi
exit 0

%ifarch %{plugin_arches}
%post plugin
update-alternatives \
    --install %{_libdir}/browser-plugins/javaplugin.so javaplugin %{pluginpath}/%{pluginname} %{priority} \
    --slave %{_bindir}/ControlPanel            ControlPanel                %{jrebindir}/ControlPanel \
    --slave %{_datadir}/javaws                 javaws                      %{jrebindir}/javaws

%postun plugin
if [ $1 -eq 0 ] ; then
update-alternatives --remove javaplugin %{pluginpath}/%{pluginname}
fi
%endif

%post
update-alternatives --install %{_bindir}/java java %{jrebindir}/java %{priority} \
    --slave %{_jvmdir}/jre                     jre                         %{_jvmdir}/%{jrelnk} \
    --slave %{_jvmjardir}/jre                  jre_exports                 %{_jvmjardir}/%{jrelnk} \
    --slave %{_bindir}/keytool                 keytool                     %{jrebindir}/keytool \
    --slave %{_bindir}/policytool              policytool                  %{jrebindir}/policytool \
    --slave %{_bindir}/rmid                    rmid                        %{jrebindir}/rmid \
    --slave %{_bindir}/rmiregistry             rmiregistry                 %{jrebindir}/rmiregistry \
    --slave %{_bindir}/tnameserv               tnameserv                   %{jrebindir}/tnameserv \
    --slave %{_bindir}/jexec                   jexec                       %{jrelibdir}/jexec \
    --slave %{_bindir}/jextract                jextract                    %{jrebindir}/jextract \
    --slave %{_bindir}/jjs                     jjs                         %{jrebindir}/jjs \
    --slave %{_bindir}/pack200                 pack200                     %{jrebindir}/pack200 \
    --slave %{_bindir}/unpack200               unpack200                   %{jrebindir}/unpack200

update-alternatives --install %{_jvmdir}/jre-ibm jre_ibm %{_jvmdir}/%{jrelnk} %{priority} \
    --slave %{_jvmjardir}/jre-ibm              jre_ibm_exports             %{_jvmjardir}/%{jrelnk}

update-alternatives --install %{_jvmdir}/jre-%{javaver} jre_%{javaver} %{_jvmdir}/%{jrelnk} %{priority} \
    --slave %{_jvmjardir}/jre-%{javaver}       jre_%{javaver}_exports      %{_jvmjardir}/%{jrelnk}

# Remove obsolete policy files
update-alternatives --remove-all jce_1.8.0_ibm_local_policy 2>/dev/null ||:

update-alternatives \
  --install \
    %{_jvmdir}/%{jrelnk}/lib/security/policy/unlimited/local_policy.jar \
    jce_%{javaver}_ibm_unlimited_local_policy \
    %{_jvmprivdir}/%{sdklnk}/jce/vanilla/unlimited/local_policy.jar \
    1803 \
  --slave \
    %{_jvmdir}/%{jrelnk}/lib/security/policy/unlimited/US_export_policy.jar \
    jce_%{javaver}_ibm_unlimited_us_export_policy \
    %{_jvmprivdir}/%{sdklnk}/jce/vanilla/unlimited/US_export_policy.jar \
  --slave \
    %{_jvmdir}/%{jrelnk}/lib/security/policy/limited/local_policy.jar \
    jce_%{javaver}_ibm_limited_local_policy \
    %{_jvmprivdir}/%{sdklnk}/jce/vanilla/limited/local_policy.jar \
  --slave \
    %{_jvmdir}/%{jrelnk}/lib/security/policy/limited/US_export_policy.jar \
    jce_%{javaver}_ibm_limited_us_export_policy \
    %{_jvmprivdir}/%{sdklnk}/jce/vanilla/limited/US_export_policy.jar

%desktop_database_post

%post devel
update-alternatives --install %{_bindir}/javac javac %{sdkbindir}/javac %{priority} \
    --slave %{_jvmdir}/java                     java_sdk                    %{_jvmdir}/%{sdklnk} \
    --slave %{_jvmjardir}/java                  java_sdk_exports            %{_jvmjardir}/%{sdklnk} \
    --slave %{_bindir}/appletviewer             appletviewer                %{sdkbindir}/appletviewer \
    --slave %{_bindir}/extcheck                 extcheck                    %{sdkbindir}/extcheck \
    --slave %{_bindir}/idlj                     idlj                        %{sdkbindir}/idlj \
    --slave %{_bindir}/jar                      jar                         %{sdkbindir}/jar \
    --slave %{_bindir}/jdeps                    jdeps                       %{sdkbindir}/jdeps \
    --slave %{_bindir}/jarsigner                jarsigner                   %{sdkbindir}/jarsigner \
    --slave %{_bindir}/javadoc                  javadoc                     %{sdkbindir}/javadoc \
    --slave %{_bindir}/javah                    javah                       %{sdkbindir}/javah \
    --slave %{_bindir}/javap                    javap                       %{sdkbindir}/javap \
    --slave %{_bindir}/jdb                      jdb                         %{sdkbindir}/jdb \
    --slave %{_bindir}/native2ascii             native2ascii                %{sdkbindir}/native2ascii \
    --slave %{_bindir}/rmic                     rmic                        %{sdkbindir}/rmic \
    --slave %{_bindir}/serialver                serialver                   %{sdkbindir}/serialver \
    --slave %{_bindir}/jconsole                 jconsole                    %{sdkbindir}/jconsole

update-alternatives --install %{_jvmdir}/java-ibm java_sdk_ibm %{_jvmdir}/%{sdklnk} %{priority} \
    --slave %{_jvmjardir}/java-ibm        java_sdk_ibm_exports     %{_jvmjardir}/%{sdklnk}
update-alternatives --install %{_jvmdir}/java-%{javaver} java_sdk_%{javaver} %{_jvmdir}/%{sdklnk} %{priority} \
    --slave %{_jvmjardir}/java-%{javaver}       java_sdk_%{javaver}_exports      %{_jvmjardir}/%{sdklnk}

%desktop_database_post

%preun
# Fix compat symlinks
# This can't be done directly because SLE10/11 would remove wrong files
if [ $1 = 0 ] ; then
  rm -f %{_jvmdir}/%{sdkcompatdir}
  rm -f %{_jvmjardir}/%{sdkcompatdir}
  rm -f %{_jvmprivdir}/%{name}
fi

%posttrans
# Fix compat symlinks
# This can't be done directly because SLE10/11 would remove wrong files
pushd %{_jvmdir} &> /dev/null
rm -f %{sdkcompatdir}
ln -s %{sdkdir} %{sdkcompatdir}
popd &> /dev/null
pushd %{_jvmjardir} &> /dev/null
rm -f %{sdkcompatdir}
ln -s %{sdkdir} %{sdkcompatdir}
popd &> /dev/null
pushd %{_jvmprivdir} &> /dev/null
rm -f %{name}
ln -s %{sdklnk} %{name}
popd &> /dev/null
exit 0

%postun
if [ $1 -eq 0 ]; then
  update-alternatives --remove java %{jrebindir}/java
  update-alternatives --remove jce_%{javaver}_ibm_unlimited_local_policy %{_jvmprivdir}/%{sdklnk}/jce/vanilla/unlimited/local_policy.jar
  update-alternatives --remove jre_ibm %{_jvmdir}/%{jrelnk}
  update-alternatives --remove jre_%{javaver} %{_jvmdir}/%{jrelnk}
fi

%desktop_database_postun

%postun devel
if [ $1 -eq 0 ]; then
  update-alternatives --remove javac %{sdkbindir}/javac
  update-alternatives --remove java_sdk_ibm %{_jvmdir}/%{sdklnk}
  update-alternatives --remove java_sdk_%{javaver} %{_jvmdir}/%{sdklnk}
fi

%desktop_database_postun

%files
%defattr(-,root,root,0755)
%doc copyright license_en.txt notices.txt readme.txt release
%{_jvmdir}/%{sdkcompatdir}
%dir %{_jvmdir}/%{sdkdir}
%{_jvmdir}/%{jrelnk}
%{_jvmjardir}/%{jrelnk}
%{_jvmjardir}/%{sdkcompatdir}
%{_jvmjardir}/%{sdkdir}/
%dir %{_jvmdir}/%{sdkdir}/jre/
%dir %{_jvmdir}/%{sdkdir}/jre/bin
%dir %{_jvmdir}/%{sdkdir}/jre/bin/classic
%dir %{_jvmdir}/%{sdkdir}/jre/bin/j9vm
%dir %{_jvmdir}/%{sdkdir}/jre/lib
%dir %{_libdir}/jvm-exports
#bnc#823034: mark binaries as executable
#need to make explicit as new rpm fails on attr applied on a symlink (ControlPanel)
%attr(0755,root,root) %{_jvmdir}/%{sdkdir}/jre/bin/ikeycmd
%attr(0755,root,root) %{_jvmdir}/%{sdkdir}/jre/bin/ikeyman
%attr(0755,root,root) %{_jvmdir}/%{sdkdir}/jre/bin/java
%attr(0755,root,root) %{_jvmdir}/%{sdkdir}/jre/bin/javaw
%ifnarch s390 s390x
%attr(0755,root,root) %{_jvmdir}/%{sdkdir}/jre/bin/javaws
%attr(0755,root,root) %{_jvmdir}/%{sdkdir}/jre/bin/jcontrol
%endif
%ifarch s390x
%attr(0755,root,root) %{_jvmdir}/%{sdkdir}/jre/bin/hwkeytool
%endif
%attr(0755,root,root) %{_jvmdir}/%{sdkdir}/jre/bin/jdmpview
%attr(0755,root,root) %{_jvmdir}/%{sdkdir}/jre/bin/jextract
%attr(0755,root,root) %{_jvmdir}/%{sdkdir}/jre/bin/jjs
%attr(0755,root,root) %{_jvmdir}/%{sdkdir}/jre/bin/keytool
%attr(0755,root,root) %{_jvmdir}/%{sdkdir}/jre/bin/kinit
%attr(0755,root,root) %{_jvmdir}/%{sdkdir}/jre/bin/klist
%attr(0755,root,root) %{_jvmdir}/%{sdkdir}/jre/bin/ktab
%attr(0755,root,root) %{_jvmdir}/%{sdkdir}/jre/bin/pack200
%attr(0755,root,root) %{_jvmdir}/%{sdkdir}/jre/bin/policytool
%attr(0755,root,root) %{_jvmdir}/%{sdkdir}/jre/bin/rmid
%attr(0755,root,root) %{_jvmdir}/%{sdkdir}/jre/bin/rmiregistry
%attr(0755,root,root) %{_jvmdir}/%{sdkdir}/jre/bin/tnameserv
%attr(0755,root,root) %{_jvmdir}/%{sdkdir}/jre/bin/unpack200
# just symlinks, package w/o attr
%ifnarch s390 s390x
%{_jvmdir}/%{sdkdir}/jre/bin/ControlPanel
%endif
%{_jvmdir}/%{sdkdir}/jre/bin/classic/libjvm.so
%{_jvmdir}/%{sdkdir}/jre/bin/j9vm/libjvm.so
# jre/lib
%{_jvmdir}/%{sdkdir}/jre/lib/%{archinstall}/
%ifarch %ix86 x86_64
%exclude %{_jvmdir}/%{jredir}/lib/%{archinstall}/libjsoundalsa.so
%endif
%{_jvmdir}/%{sdkdir}/jre/lib/applet/
%{_jvmdir}/%{sdkdir}/jre/lib/cmm/
%{_jvmdir}/%{sdkdir}/jre/lib/ddr/
%ifnarch s390 s390x
%{_jvmdir}/%{sdkdir}/jre/lib/deploy/
%{_jvmdir}/%{sdkdir}/jre/lib/desktop/
%endif
%{_jvmdir}/%{sdkdir}/jre/lib/ext/
%{_jvmdir}/%{sdkdir}/jre/lib/fonts/
%{_jvmdir}/%{sdkdir}/jre/lib/images/
%{_jvmdir}/%{sdkdir}/jre/lib/tools/
%ifnarch ppc64 ppc64le s390 s390x
%{_jvmdir}/%{sdkdir}/jre/lib/locale/
%endif
%{_jvmdir}/%{sdkdir}/jre/lib/oblique-fonts/
%dir %{_jvmdir}/%{jredir}/lib/management/
%dir %{_jvmdir}/%{jredir}/lib/security
%{_jvmdir}/%{sdkdir}/jre/lib/*dat
%{_jvmdir}/%{sdkdir}/jre/lib/*jar
%ifarch %{plugin_arches}
%exclude %{_jvmdir}/%{jredir}/lib/plugin.jar
%exclude %{pluginpath}/%{pluginname}
%endif
%{_jvmdir}/%{sdkdir}/jre/lib/classlist
%{_jvmdir}/%{sdkdir}/jre/lib/currency.data
%{_jvmdir}/%{sdkdir}/jre/lib/ibmversions.txt
%{_jvmdir}/%{sdkdir}/jre/lib/ir.idl
%{_jvmdir}/%{sdkdir}/jre/lib/jexec
%{_jvmdir}/%{sdkdir}/jre/lib/jexec.diz
%{_jvmdir}/%{sdkdir}/jre/lib/jaxp.properties.sample
%{_jvmdir}/%{sdkdir}/jre/lib/jvm.hprof.txt
%{_jvmdir}/%{sdkdir}/jre/lib/meta-index
%{_jvmdir}/%{sdkdir}/jre/lib/orb.idl
%{_jvmdir}/%{sdkdir}/jre/lib/stax.properties.sample
%{_jvmdir}/%{sdkdir}/jre/lib/tzmappings
%{_jvmdir}/%{sdkdir}/jre/lib/icc/
%{_jvmdir}/%{sdkdir}/jre/lib/icc/C/icc/
%{_jvmdir}/%{sdkdir}/jre/lib/icc/C/icc/icclib/
%{_jvmdir}/%{sdkdir}/jre/lib/icc/N/icc/
%{_jvmdir}/%{sdkdir}/jre/lib/icc/N/icc/icclib/
%ifarch ppc64le ppc64 s390x x86_64
%{_jvmdir}/%{sdkdir}/jre/fips140-2/
%{_jvmdir}/%{sdkdir}/jre/fips140-2/lib/
%{_jvmdir}/%{sdkdir}/jre/fips140-2/lib/ext/
%{_jvmdir}/%{sdkdir}/jre/fips140-3/
%{_jvmdir}/%{sdkdir}/jre/fips140-3/lib/
%{_jvmdir}/%{sdkdir}/jre/fips140-3/lib/ext/
%{_jvmdir}/%{sdkdir}/jre/fips140-3/lib/icc/
%{_jvmdir}/%{sdkdir}/jre/fips140-3/lib/icc/C/icc/
%{_jvmdir}/%{sdkdir}/jre/fips140-3/lib/icc/C/icc/icclib/
%{_jvmdir}/%{sdkdir}/jre/fips140-3/lib/icc/N/icc/
%{_jvmdir}/%{sdkdir}/jre/fips140-3/lib/icc/N/icc/icclib/
%{_jvmdir}/%{sdkdir}/jre/fips140-3/lib/ibmjsseprovider2.jar
%{_jvmdir}/%{sdkdir}/jre/fips140-3/lib/classlib.properties
%{_jvmdir}/%{sdkdir}/jre/fips140-3/lib/security/
%{_jvmdir}/%{sdkdir}/jre/fips140-3/lib/security/java.security
%{_jvmdir}/%{sdkdir}/jre/fips140-3/lib/security/cacerts
%endif
%if 0%{?suse_version} > 1210
%{_jvmdir}/%{jredir}/lib/security/cacerts
%else
%config(noreplace) %{_jvmdir}/%{jredir}/lib/security/cacerts
%endif
%config(noreplace) %{_jvmdir}/%{jredir}/lib/security/java.policy
%config(noreplace) %{_jvmdir}/%{jredir}/lib/security/java.security
%config(noreplace) %{_jvmdir}/%{jredir}/lib/security/blacklist
%config(noreplace) %{_jvmdir}/%{jredir}/lib/security/blacklisted.certs
%config(noreplace) %{_jvmdir}/%{jredir}/lib/security/trusted.libraries
#bnc#637224
%config(noreplace) %{_jvmdir}/%{jredir}/lib/font*
%config(noreplace) %{_jvmdir}/%{jredir}/lib/*.properties
%config(noreplace) %{_jvmdir}/%{jredir}/lib/psfont.properties.ja
%config(noreplace) %{_jvmdir}/%{jredir}/lib/management/*
%config(noreplace) %{_jvmdir}/%{jredir}/lib/images/cursors/cursors.properties
%dir %{_jvmdir}/%{jredir}/lib/security/policy/
%dir %{_jvmdir}/%{jredir}/lib/security/policy/limited/
%dir %{_jvmdir}/%{jredir}/lib/security/policy/unlimited/
%ghost %{_jvmdir}/%{jredir}/lib/security/policy/limited/local_policy.jar
%ghost %{_jvmdir}/%{jredir}/lib/security/policy/limited/US_export_policy.jar
%ghost %{_jvmdir}/%{jredir}/lib/security/policy/unlimited/local_policy.jar
%ghost %{_jvmdir}/%{jredir}/lib/security/policy/unlimited/US_export_policy.jar
%{_jvmprivdir}/%{name}
%{_jvmprivdir}/%{sdklnk}/
%{_jvmprivdir}/%{sdklnk}/jce/vanilla
%config(noreplace) %{_jvmprivdir}/%{sdklnk}/jce/vanilla/limited/*_policy.jar
%config(noreplace) %{_jvmprivdir}/%{sdklnk}/jce/vanilla/unlimited/*_policy.jar
%ifarch %{plugin_arches}
#bnc#752306
%exclude %{_jvmdir}/%{sdkdir}/jre/lib/locale/*/LC_MESSAGES/*plugin.mo
%exclude %{_jvmdir}/%{sdkdir}/jre/plugin/desktop/sun_java.png
%endif
%ifarch ppc64
%{_jvmdir}/%{sdkdir}/jre/plugin/
%{_jvmdir}/%{sdkdir}/jre/plugin/desktop
%endif
%ifarch ppc64le ppc ppc64 %{plugin_arches}
#bnc#752306
%config(noreplace) %{_jvmdir}/%{jredir}/lib/security/javaws.policy
%endif
%dir %{_jvmdir}/%{jredir}/.systemPrefs
%{_jvmdir}/%{jredir}/.qa_filelist.%{_arch}

%files devel
%defattr(-,root,root,0755)
%{_jvmdir}/%{sdklnk}
%dir %{_jvmdir}/%{sdkdir}
%dir %{_jvmdir}/%{sdkdir}/bin
%dir %{_jvmdir}/%{sdkdir}/include
%dir %{_jvmdir}/%{sdkdir}/lib
#bnc#823034: mark binaries as executable
#need to make explicit as new rpm fails on attr applied on a symlink (ControlPanel et all)
%attr(0755,root,root) %{_jvmdir}/%{sdkdir}/bin/appletviewer
%attr(0755,root,root) %{_jvmdir}/%{sdkdir}/bin/extcheck
%attr(0755,root,root) %{_jvmdir}/%{sdkdir}/bin/idlj
%attr(0755,root,root) %{_jvmdir}/%{sdkdir}/bin/jdeps
%attr(0755,root,root) %{_jvmdir}/%{sdkdir}/bin/jjs
%attr(0755,root,root) %{_jvmdir}/%{sdkdir}/bin/jar
%attr(0755,root,root) %{_jvmdir}/%{sdkdir}/bin/jarsigner
%attr(0755,root,root) %{_jvmdir}/%{sdkdir}/bin/javac
%attr(0755,root,root) %{_jvmdir}/%{sdkdir}/bin/javadoc
%attr(0755,root,root) %{_jvmdir}/%{sdkdir}/bin/javah
%attr(0755,root,root) %{_jvmdir}/%{sdkdir}/bin/javap
%attr(0755,root,root) %{_jvmdir}/%{sdkdir}/bin/java-rmi.cgi
%attr(0755,root,root) %{_jvmdir}/%{sdkdir}/bin/jconsole
%ifnarch s390 s390x
%attr(0755,root,root) %{_jvmdir}/%{sdkdir}/bin/javaws
%attr(0755,root,root) %{_jvmdir}/%{sdkdir}/bin/jcontrol
%endif
%ifarch s390x
%attr(0755,root,root) %{_jvmdir}/%{sdkdir}/bin/hwkeytool
%endif
%attr(0755,root,root) %{_jvmdir}/%{sdkdir}/bin/jdb
%attr(0755,root,root) %{_jvmdir}/%{sdkdir}/bin/jdmpview
%attr(0755,root,root) %{_jvmdir}/%{sdkdir}/bin/jrunscript
%attr(0755,root,root) %{_jvmdir}/%{sdkdir}/bin/native2ascii
%attr(0755,root,root) %{_jvmdir}/%{sdkdir}/bin/pack200
%attr(0755,root,root) %{_jvmdir}/%{sdkdir}/bin/rmic
%attr(0755,root,root) %{_jvmdir}/%{sdkdir}/bin/schemagen
%attr(0755,root,root) %{_jvmdir}/%{sdkdir}/bin/serialver
%ifnarch s390 s390x
%attr(0755,root,root) %{_jvmdir}/%{sdkdir}/bin/tnameserv
%else
#symlink on s390
%{_jvmdir}/%{sdkdir}/bin/tnameserv
%endif
%attr(0755,root,root) %{_jvmdir}/%{sdkdir}/bin/unpack200
%attr(0755,root,root) %{_jvmdir}/%{sdkdir}/bin/wsgen
%attr(0755,root,root) %{_jvmdir}/%{sdkdir}/bin/wsimport
%attr(0755,root,root) %{_jvmdir}/%{sdkdir}/bin/xjc
# just symlinks, package w/o attr
%ifnarch s390 s390x
%{_jvmdir}/%{sdkdir}/bin/ControlPanel
%endif
%{_jvmdir}/%{sdkdir}/bin/java
%{_jvmdir}/%{sdkdir}/bin/javaw
%{_jvmdir}/%{sdkdir}/bin/keytool
%{_jvmdir}/%{sdkdir}/bin/policytool
%{_jvmdir}/%{sdkdir}/bin/rmid
%{_jvmdir}/%{sdkdir}/bin/rmiregistry
%{_jvmdir}/%{sdkdir}/include/*
%{_jvmdir}/%{sdkdir}/lib/*
%{_jvmjardir}/%{sdklnk}

%files src
%defattr(0644,root,root,0755)
%{_jvmdir}/%{sdkdir}/src.jar
%{_jvmdir}/%{sdkdir}/src.zip

%files demo
%defattr(0644,root,root,0755)
%{_jvmdir}/%{sdkdir}/demo

%ifarch %ix86 x86_64
%files alsa
%defattr(-,root,root,0755)
%{_jvmdir}/%{jredir}/lib/%{archinstall}/libjsoundalsa.so
%endif

%ifarch %{plugin_arches}
%files plugin
%defattr(644,root,root,0755)
%dir %{_jvmdir}/%{sdkdir}/jre/plugin/
%dir %{_jvmdir}/%{sdkdir}/jre/plugin/desktop
%{_datadir}/applications/jpackage-%{name}-ControlPanel.desktop
%{_datadir}/applications/jpackage-%{name}-webstart.desktop
%{_datadir}/pixmaps/ibm-java-%{javaver}.png
%{pluginpath}/%{pluginname}
%{_jvmdir}/%{jredir}/lib/plugin.jar
%{_jvmdir}/%{jredir}/lib/locale/*/LC_MESSAGES/*plugin.mo
%{_jvmdir}/%{sdkdir}/jre/plugin/desktop/sun_java.png
%ifarch ppc
%{_jvmdir}/%{jredir}/plugin/%{archinstall}/
%endif
%endif

%changelog
* Fri Nov 17 2023 pmonreal@suse.com
- Update to Java 8.0 Service Refresh 8 Fix Pack 15:
  * Oracle October 17 2023 CPU [bsc#1216640]
  * IBM Security Update October 2023 [bsc#1216640]
  * IBM Java idlj compiler switch definition because IBM java idlj
    seems to confuse char and wchar for typedef types [bsc#1204264]
  * Security fixes:
  - [bsc#1216374, CVE-2023-22081] Enhanced TLS connections
  - [bsc#1216379, CVE-2023-22067] IOR deserialization issue
    in CORBA
  - [bsc#1216339, CVE-2023-22025] Memory corruption issue on
    x86_64 with AVX-512
  - [bsc#1217214, CVE-2023-5676] Receiving a signal before
    initialization may lead to an infinite loop or unexpected
    crash.
  * Defect Fixes:
  - IJ47667 Class Libraries: Add/Edit property to write stdout/stderr
    messages via file streams
  - IJ48028 Class Libraries: IBM JAVA IDLJ COMPILER ENCOUNTER AMBIGUITY
    BETWEEN CHAR AND WCHAR FOR TYPDEF TYPES
  - IJ48844 Class Libraries: IMPROVE PERFORMANCE OF
    JAVA.LANG.PACKAGE CLASS WHEN LOOKING UP CACHED PACKAGES
  - IJ49091 Class Libraries: RFE: KERBEROS PRINCIPAL NAME
    CANONICALIZATION AND CROSS-REALM REFERRALS (RFC 6806, SECTION 8)
  - IJ47751 Java Virtual Machine: ASSERTION FAILURE AT
    PARALLELSCAVENGETASK.CPP:120
  - IJ48453 Security: IBMJCEPLUS/IBMJCEPLUSFIPS PROVIDERS, DURING
    AESGCM, THROW AN INCORRECT ILLEGALSTATEEXCEPTION:CIPHER NOT
    INITIALIZED
  - IJ47691 Security: JGSS: HIGH MEMORY USE FROM LSACONNECTUNTRUSTED()
    CALLS IN NATIVECREDS.DLL
  - IJ48749 Security: KEYTOOL ERROR WHEN A KEYSTORE IS CREATED WITH
    '-EXT EXTENDEDKEYUSAGE=SERVERAUTH'
  - IJ49092 Security: RFE: KERBEROS PRINCIPAL NAME CANONICALIZATION
    AND CROSS-REALM REFERRALS (RFC 6806, SECTION 8)
  - IJ47941 Security: STRICT ENFORCEMENT OF RFC 5246 - TLS 1.2
    SECTION 7.4.1.4.1. SIGNATURE ALGORITHMS
  - PH55605 z/OS Extentions: ECDSA SIGNATURE SUPPORT FOR IBMJCEHYBRID
  - PH55999 z/OS Extentions: JAVA8 - ENCOUNTERING -430 ON FUNCTION
    DB2XML.HTTPGETCLOB
  - PH56022 z/OS Extentions: TLSV1.3 SUPPORT USING RACF RSA HARDWARE
    AND SOFTWARE KEYS WITH DIFFERENT SIGNING ALGORITHMS
* Thu Sep 28 2023 pmonreal@suse.com
- Update to Java 8.0 Service Refresh 8 Fix Pack 11
  * Defect Fixes:
  - IJ47696 Class Libraries: Code conversion issue for graphic
    data type for the data ranging from 0x0040 and 0x0042 to 0x00f9
  - IJ47427 JIT Compiler: Crash with adjacent malformed objects
  - IJ47675 JIT Compiler: JAVA JIT: Divide by zero in
    computeThreadCpuUtilOverLastNns()
  - IJ48654 JIT Compiler: JAVA JIT: GC crash in doStackSlot()
    on POWER10
  - PH57123 z/OS Extentions: IBMPKCS11Impl fails to initialize
    after customer migrated from z/OS 2.5 to z/OS 3.1
* Mon Aug 21 2023 pmonreal@suse.com
- IBM Security Update August 2023:
  * [bsc#1214431, bsc#1213934, CVE-2022-40609]
  * IBM SDK, Java Technology Edition could allow a remote attacker
    to execute arbitrary code on the system, caused by an unsafe
    deserialization flaw.
  * Note that, this vulnerability was fixed in the already released
    version 8.0.8.5 as reported in the IBM advisory, adding the
    reference here.
* Mon Aug 21 2023 pmonreal@suse.com
- Update to Java 8.0 Service Refresh 8 Fix Pack 10 [bsc#1213541]
  * Security fixes:
    [bsc#1213475, CVE-2023-22041] [bsc#1213482, CVE-2023-22049]
    [bsc#1213481, CVE-2023-22045] [bsc#1213479, CVE-2023-22044]
    [bsc#1213474, CVE-2023-22036] [bsc#1207922, CVE-2023-25193]
    [bsc#1213473, CVE-2023-22006]
* Wed Jul  5 2023 pmonreal@suse.com
- Update to Java 8.0 Service Refresh 8 Fix Pack 6 [bsc#1213000]
  * Defect Fixes:
  - Java Virtual Machine: outofmemory (OOM) killer terminates
    the jvm due to failure in control groups detection.
* Tue Jun  6 2023 pmonreal@suse.com
- Update to Java 8.0 Service Refresh 8 Fix Pack 5 [bsc#1210826]
  * Security Fixes:
  - IJ46965 Class Libraries: [bsc#1210628, CVE-2023-21930]
  - IJ46972 Class Libraries: [bsc#1210631, CVE-2023-21937]
  - IJ46974 Class Libraries: [bsc#1210632, CVE-2023-21938]
  - IJ46969 Class Libraries: [bsc#1210634, CVE-2023-21939]
  - IJ46971 Class Libraries: [bsc#1210637, CVE-2023-21968]
  - IJ47000 Java Virtual Machine: [bsc#1211615, CVE-2023-2597]
  - IJ46967 Security: [bsc#1210636, CVE-2023-21967]
  - Vulnerability in the Oracle Java SE, Oracle GraalVM
    Enterprise Edition product of Oracle Java SE (component:
    Hotspot). [bsc#1210635, CVE-2023-21954]
  * Defect Fixes:
  - IX90194 Java 8/Orb: ORB'S SOCKET TIMER THREAD HANGS IN COM.IBM.JSSE2
  - IJ47092 Class Libraries: DEPRECATION OF RDMA
  - IJ45888 Java Virtual Machine: ASSERTION FAILURE AT SCAVENGER.CPP
  - IJ46813 Java Virtual Machine: JVM'S SIGUSR2 SIGNAL HANDLER
    OVERWRITES NATIVE APP'S SIGUSR2 SIGNAL HANDLER
  - IJ47094 Java Virtual Machine: FIX THE MISMATCHED FLAGS IN THE
    STACKMAPS OF BYTECODE DURING THE BYTECODE VERIFICATION
  - IJ45583 Java Virtual Machine: SOME CODE FOR IBM JAVA 8 COMPILED
    WITH ARCH(10) ON Z/OS
  - IJ46192 JIT Compiler: CRASH WHEN USING IBMJCEPLUS WITH BALANCED GC
  - IJ45659 JIT Compiler: JAVA JIT: MISSING TYPE CHECKING ALLOWED
    INVALID OBJECT FIELD ACCESSES
  - IJ46620 Security: ADD NEW SUPPORT FOR RSAPSS SIGNATURES RECEIVED
    BY CERTPATH WITHIN OCSP RESPONSES
  - IJ45919 Security: DISABLE RSA KEY TRANSPORT CIPHER SUITES IN
    FIPS 140-3 TECH PREVIEW
  - IJ46173 Security: IBMJCEPLUS, IBMJCEPLUSFIPS PROVIDERS THROW AN
    INCORRECT JAVA.SECURITY.SIGNATUREEXCEPTION
  - IJ45883 Security: IBMJCEPLUSFIPS PROVIDER FAILS DURING SIGNATURE
    OPERATIONS USING NON FIPS140-2 COMPLIANT EC KEYS.
  - IJ45182 Security: IBMJCEPLUS PROVIDER FAILS IN RSAPSS DURING
    SIGNATURE OPERATIONS RESULTING IN JAVA CORES.
  - IJ46193 Security: SSLCONTEXT.GETINSTANCE FAILURES CAUSE
    JAVA.LANG.EXCEPTIONININITIALIZERERROR
  - IJ45599 Security: UPDATE IKEYMAN TO SUPPORT PBES2 AND OTHER MINOR
    FIXES
  - IJ45598 Security: UPDATE KDB FORMAT TO SUPPORT PBES2
  - IJ45789 Security: -XVERIFY:ALL CAUSES FAILURE IN JSSE
  - PH52970 z/OS Extentions: CHACHA20-POLY1305 CIPHER DECRYPTION CHUNK
    UPDATE FIX
  - PH52876 z/OS Extentions: RSA-PSS SIGNATURE SUPPORT FOR RSA HARDWARE
    KEYS OVER TLSV1.3
* Tue Apr 25 2023 pmonreal@suse.com
- IBM Security Update April 2023: [bsc#1210711, CVE-2023-30441]
  * The security vulnerability CVE-2023-30441 was fixed in version
    8.0.7.15 as reported in the advisory, adding the reference here.
* Mon Apr  3 2023 pmonreal@suse.com
- Update to Java 8.0 Service Refresh 8: [bsc#1208480]
  * Security fixes: [bsc#1207246, CVE-2023-21835]
    [bsc#1207249, CVE-2023-21830] [bsc#1207248, CVE-2023-21843]
  * New Features/Enhancements:
  - Add RSA-PSS signature to IBMJCECCA.
  * Defect Fixes:
  - IJ45437 Service, Build, Packaging and Deliver: Getting
    FIPSRUNTIMEEXCEPTION when calling java code:
    MESSAGEDIGEST.GETINSTANCE("SHA256", "IBMJCEFIPS"); in MAC
  - IJ45272 Class Libraries: Fix security vulnerability CVE-2023-21843
  - IJ45280 Class Libraries: Update timezone information to the
    latest TZDATA2022F
  - IJ44896 Class Libraries: Update timezone information to the
    latest TZDATA2022G
  - IJ45436 Java Virtual Machine: Stack walking code gets into
    endless loop, hanging the application
  - IJ44079 Java Virtual Machine: When -DFILE.ENCODING is specified
    multiple times on the same command line the first option takes
    precedence instead of the last
  - IJ44532 JIT Compiler: Java JIT: Crash in DECREFERENCECOUNT()
    due to a NULL pointer
  - IJ44596 JIT Compiler: Java JIT: Invalid hard-coding of static
    final field object properties
  - IJ44107 JIT Compiler: JIT publishes new object reference to other
    threads without executing a memory flush
  - IX90193 ORB: Fix security vulnerability CVE-2023-21830
  - IJ44267 Security: 8273553: SSLENGINEIMPL.CLOSEINBOUND also has
    similar error of JDK-8253368
  - IJ45148 Security: code changes for tech preview
  - IJ44621 Security: Computing Diffie-Hellman secret repeatedly,
    using IBMJCEPLUS, causes a small memory leak
  - IJ44172 Security: Disable SHA-1 signed jars for EA
  - IJ44040 Security: Generating Diffie-Hellman key pairs repeatedly,
    using IBMJCEPLUS, Causes a small memory leak
  - IJ45200 Security: IBMJCEPLUS provider, during CHACHA20-POLY1305
    crypto operations, incorrectly throws an ILLEGALSTATEEXCEPTION
  - IJ45182 Security: IBMJCEPLUS provider fails in RSAPSS and ECDSA
    during signature operations resulting in Java cores
  - IJ45201 Security: IBMJCEPLUS provider failures (two) with AESGCM algorithm
  - IJ45202 Security: KEYTOOL NPE if signing certificate does not contain
    a SUBJECTKEYIDENTIFIER extension
  - IJ44075 Security: PKCS11KEYSTORE.JAVA - DOESPUBLICKEYMATCHPRIVATEKEY()
    method uses SHA1XXXX signature algorithms to match private and public keys
  - IJ45203 Security: RSAPSS multiple names for KEYTYPE
  - IJ43920 Security: The PKCS12 keystore update and the PBES2 support
  - IJ40002 XML: Fix security vulnerability CVE-2022-21426
* Thu Dec 15 2022 pmonreal@suse.com
- IBM Security Update November 2022: [bsc#1205302, bsc#1204703]
  * The security vulnerability CVE-2022-3676 was fixed in version
    8.0.7.20, adding the reference here.
* Fri Nov 11 2022 pmonreal@suse.com
- Update to Java 8.0 Service Refresh 7 Fix Pack 20 [bsc#1205302]
  [bsc#1204472, CVE-2022-21628] [bsc#1204471, CVE-2022-21626]
  [bsc#1204468, CVE-2022-21618] [bsc#1204480, CVE-2022-39399]
  [bsc#1204475, CVE-2022-21624] [bsc#1204473, CVE-2022-21619]
  * Security:
  - The IBM ORB Does Not Support Object-Serialisation Data Filtering
  - Large Allocation In CipherSuite
  - Avoid Evaluating Sslalgorithmconstraints Twice
  - Cache The Results Of Constraint Checks
  - An incorrect ShortBufferException is thrown by IBMJCEPlus,
    IBMJCEPlusFIPS during cipher update operation
  - Disable SHA-1 Signed Jars For Ea
  - JSSE Performance Improvement
  - Oracle Road Map Kerberos Deprecation Of 3DES And RC4 Encryption
  * Java 8/Orb:
  - Upgrade ibmcfw.jar To Version o2228.02
  * Class Libraries:
  - Crash In Libjsor.So During An Rdma Failover
  - High CPU Consumption Observed In ZosEventPort$EventHandlerTask.run
  - Update Timezone Information To The Latest tzdata2022c
  * Jit Compiler:
  - Crash During JIT Compilation
  - Incorrect JIT Optimization Of Java Code
  - Incorrect Return From Class.isArray()
  - Unexpected ClassCastException
  - Performance Regression When Calling VM Helper Code On X86
  * X/Os Extentions:
  - Add RSA-OAEP Cipher Function To IBMJCECCA
* Fri Oct 14 2022 pmonreal@suse.com
- Update to Java 8.0 Service Refresh 7 Fix Pack 16
  * Java Virtual Machine
  - Assertion failure at ClassLoaderRememberedSet.cpp
  - Assertion failure at StandardAccessBarrier.cpp when
  - Xgc:concurrentScavenge is set.
  - GC can have unflushed ownable synchronizer objects which
  can eventually lead to heap corruption and failure when
  - Xgc:concurrentScavenge is set.
  * JIT Compiler:
  - Incorrect JIT optimization of Java code
  - JAVA JIT Power: JIT compile time assert on AIX or LINUXPPC
  * Reliability and Serviceability:
  - javacore with "kill -3" SIGQUIT signal freezes Java process
* Mon Aug 29 2022 pmonreal@suse.com
- Update to Java 8.0 Service Refresh 7 Fix Pack 15 [bsc#1202427]
  [bsc#1201684, CVE-2022-34169] [bsc#1201692, CVE-2022-21541]
  [bsc#1201685, CVE-2022-21549] [bsc#1201694, CVE-2022-21540]
  * Correction: These CVEs have been fixed in version 8.0-7.15 and
    not in 8.0-7.11 as mentioned in the previous changelog entry.
* Fri Aug 12 2022 pmonreal@suse.com
- Update to Java 8.0 Service Refresh 7 Fix Pack 11 [bsc#1202427]
  [bsc#1201684, CVE-2022-34169] [bsc#1201692, CVE-2022-21541]
  [bsc#1201685, CVE-2022-21549] [bsc#1201694, CVE-2022-21540]
  * Defect Fixes:
  - Java Virtual Machine: Long dely in AttachAPI
* Mon Jul 18 2022 pmonreal@suse.com
- Update to Java 8.0 Service Refresh 7 Fix Pack 10 [bsc#1201643]
  [bsc#1198671, CVE-2022-21476] [bsc#1198670, CVE-2022-21449]
  [bsc#1198673, CVE-2022-21496] [bsc#1198674, CVE-2022-21434]
  [bsc#1198672, CVE-2022-21426] [bsc#1198675, CVE-2022-21443]
  [bsc#1191912, CVE-2021-35561] [bsc#1194931, CVE-2022-21299]
  * Class Libraries:
  - BigDecimal gives incorrect arithmetic results for the add
    and subtract operations on the result of a divide
  * Java Virtual Machine:
  - jstacktrace sub-option of xtrace doesn't print java stack
    while doing method trace
  * Security:
  - 8217633: Configurable Extensions with system properties
  - 8241248: NullPointerException in com.ibm.jsse2.ssl.HKDF.extract
  - 8270344: Session resumption errors
  - 8277967: Validate the SSLLogger object in KeyShareExtension
  - JVM crashes computing Diffie-Hellman shared secrets and JNI
    errors while creating elliptic curve public key using IBMJCEPlus
  - Key Certificate Manager authority key identifier value incorrect
  - SSLv2Hello property value is ignored if specified in
    jdk.tls.disabledAlgorithms and SSLv2Hello is set by
    setEnabledProtocols()
  - There is a memory growth observed during digest operations
    using IBMJCEPlus as the provider.
* Mon Jul 18 2022 pmonreal@suse.com
- Update to Java 8.0 Service Refresh 7 Fix Pack 6
  * Java Virtual Machine: Crash while generating javacore, or
    javacore contains 'Unable to walk in-flight data on call stack'
    instead of java stack
  * JIT Compiler:
  - Java JIT, bad field reference from a tenured object into
    the nursery
  - JIT compiler crash with vmstate=0x0005ff04
  * XML: Fix security vulnerability CVE-2022-21299
* Tue Mar 15 2022 pmonreal@suse.com
- Update to Java 8.0 Service Refresh 7 Fix Pack 5 [bsc#1197126]
  * https://www.ibm.com/support/pages/java-sdk-security-vulnerabilities
    [bsc#1194927, CVE-2022-21366] [bsc#1194928, CVE-2022-21365]
    [bsc#1194929, CVE-2022-21360] [bsc#1196500, CVE-2022-21349]
    [bsc#1194941, CVE-2022-21341] [bsc#1194940, CVE-2022-21340]
    [bsc#1194939, CVE-2022-21305] [bsc#1194930, CVE-2022-21277]
    [bsc#1194931, CVE-2022-21299] [bsc#1194932, CVE-2022-21296]
    [bsc#1194933, CVE-2022-21282] [bsc#1194934, CVE-2022-21294]
    [bsc#1194935, CVE-2022-21293] [bsc#1194925, CVE-2022-21291]
    [bsc#1194937, CVE-2022-21283] [bsc#1194926, CVE-2022-21248]
    [CVE-2022-21271]
* Tue Mar 15 2022 pmonreal@suse.com
- Fix a javaws broken symlink [bsc#1195146]
* Mon Jan  3 2022 pmonreal@suse.com
- Update to Java 8.0 Service Refresh 7 Fix Pack 0 [bsc#1194232]
  [bsc#1194198, bsc#1192052, CVE-2021-41035]
  [bsc#1191902, CVE-2021-35560] [bsc#1191904, CVE-2021-35578]
  [bsc#1191914, CVE-2021-35586] [bsc#1191913, CVE-2021-35564]
  [bsc#1191911, CVE-2021-35559] [bsc#1191910, CVE-2021-35556]
  [bsc#1191909, CVE-2021-35565] [bsc#1191905, CVE-2021-35588]
- Update to Java 8.0 Service Refresh 6 Fix Pack 35
  [bsc#1188565, CVE-2021-2369] [bsc#1188564, CVE-2021-2341]
* Tue Jun  1 2021 pmonreal@suse.com
- Update to Java 8.0 Service Refresh 6 Fix Pack 30
  [bsc#1185056, CVE-2021-2161][bsc#1185055, CVE-2021-2163]
  * Service, Build, Packaging and Deliver:
  - Symlink issue reported for javaws in jre packages
  - ibmjceplus security provider depends on msvcr120.dll on windows
  * Class Libraries:
  - Exception in pure ipv6 environment in IBM sdk
  - Fix security vulnerability CVE-2021-2161
  - Update cacerts to include certificates from entrust and globalsign
  - Update timezone information to the latest tzdata2021a
  * Java Virtual Machine:
  - Sssertion failed at copyforwardscheme.cpp because a tag slot
    (0x3) was treated as an object
  - GPF event from method unlinkclassloadingconstraints
  - JVM takes more time to start up
  - xgc:classunloadingkickoffthreshold not working as expected
  * JIT Compiler:
  - The JIT incorrectly compiles a method consisting of non-javac
    generated bytecodes from java 8.0.6.20 and up to 8.0.6.30
  * Security:
  - httpsurlconnection drops the timeout and hangs forever in read
  - sslsocket that is never bound or connected leaks socket resources
  - TLS connection always receives close_notify exception
  - JSSE fails to open racf keystores
  - Kerberos ticket renewal fails with debug enabled following
    java.lang.illegalstateexception
  - Update JSSE to oracle jdk8u281 fix level
* Tue Jun  1 2021 pmonreal@suse.com
- Update to Java 8.0 Service Refresh 6 Fix Pack 26
  * Java Virtual Machine:
  - Behaviour change in getmethod for java8_sr6_fp20
  - Crash when outputting to verbose GC log using the specifier
    characters
  - Outofmemoryerror happens due to nursery heap space shortage
  * JIT Compiler:
  - Occasional assertion being triggered in code generation
  - SEGV when using hashmap$hashiterator.nextnode() in
    multiple threads concurrently
* Fri Feb 12 2021 pmonreal@suse.com
- Update to Java 8.0 Service Refresh 6 Fix Pack 25
  [bsc#1182186, bsc#1181239, CVE-2020-27221, CVE-2020-14803]
  * CVE-2020-27221: Potential for a stack-based buffer overflow
    when the virtual machine or JNI natives are converting from
    UTF-8 characters to platform encoding.
  * CVE-2020-14803: Unauthenticated attacker with network access
    via multiple protocols allows to compromise Java SE.
* Tue Dec 15 2020 pmonreal@suse.com
- Update to Java 8.0 Service Refresh 6 Fix Pack 20 [bsc#1180063,bsc#1177943]
  CVE-2020-14792 CVE-2020-14797 CVE-2020-14781 CVE-2020-14779
  CVE-2020-14798 CVE-2020-14796 CVE-2020-14803
  * Class libraries:
  - SOCKETADAPTOR$SOCKETINPUTSTREAM.READ is blocking for more time
    that the set timeout
  - Z/OS specific C function send_file is changing the file pointer
    position
  * Java Virtual Machine:
  - Crash on iterate java stack
  - Java process hang on SIGTERM
  * JIT Compiler:
  - JMS performance regression from JDK8 SR5 FP40 TO FP41
* Mon Sep 28 2020 pmonreal@suse.com
- Update to Java 8.0 Service Refresh 6 Fix Pack 16
  * Java ifix for z15 compression problem [bsc#1175295]
  * Class Libraries:
  - z15 high utilization following Z/VM and Linux migration from
    z14 To z15
  * Java Virtual Machine:
  - Assertion failed when trying to write a class file
  - Assertion failure at modronapi.cpp
  - Improve the performance of defining and finding classes
  * JIT Compiler:
  - An assert in ppcbinaryencoding.cpp may trigger when running
    with traps disabled on power
  - AOT field offset off by n bytes
  - Segmentation fault in jit module on ibm z platform
* Fri Aug 14 2020 pmonreal@suse.com
- Update to Java 8.0 Service Refresh 6 Fix Pack 15 [bsc#1175259, bsc#1174157]
  CVE-2020-14577 CVE-2020-14578 CVE-2020-14579 CVE-2020-14581
  CVE-2020-14556 CVE-2020-14621 CVE-2020-14593 CVE-2020-14583
  CVE-2019-17639
  * Class Libraries:
  - JAVA.UTIL.ZIP.DEFLATER OPERATIONS THROW JAVA.LANG.INTERNALERROR
  - JAVA 8 DECODER OBJECTS CONSUME A LARGE AMOUNT OF JAVA HEAP
  - TRANSLATION MESSAGES UPDATE FOR JCL
  - UPDATE TIMEZONE INFORMATION TO TZDATA2020A
  * Java Virtual Machine:
  - IBM JAVA REGISTERS A HANDLER BY DEFAULT FOR SIGABRT
  - LARGE MEMORY FOOTPRINT HELD BY TRACECONTEXT OBJECT
  * JIT Compiler:
  - CRASH IN THE INTERPRETER AFTER OSR FROM INLINED SYNCHRONIZED METHOD
    IN DEBUGGING MODE
  - INTERMITTENT ASSERTION FAILURE REPORTED
  - CRASH IN RESOLVECLASSREF() DURING AOT LOAD
  - JIT CRASH DURING CLASS UNLOADING IN J9METHOD_HT::ONCLASSUNLOADING()
  - SEGMENTATION FAULT WHILE COMPILING A METHOD
  - UNEXPECTED CLASSCASTEXCEPTION THROWN IN HIGH LEVEL PARALLEL
    APPLICATION ON IBM Z PLATFORM
  * Security:
  - CERTIFICATEEXCEPTION OCCURS WHEN FILE.ENCODING PROPERTY SET TO
    NON DEFAULT VALUE
  - CHANGES TO IBMJCE AND IBMJCEPLUS PROVIDERS
  - IBMJCEPLUS FAILS, WHEN THE SECURITY MANAGER IS ENABLED, WITH
    DEFAULT PERMISSIONS, SPECIFIED IN JAVA.POLICY FILE
  - IN CERTAIN INSTANCES, IBMJCEPLUS PROVIDER THROWS EXCEPTION FROM
    KEYFACTORY CLASS
* Tue Jun  9 2020 pmonrealgonzalez@suse.com
- Fix update-alternatives for the 32bit packages in baselibs.conf [bsc#1171352]
* Fri May 29 2020 pmonrealgonzalez@suse.com
- The pack200 and unpack200 alternatives should be slaves of java [bsc#1171352]
* Fri May 29 2020 pmonrealgonzalez@suse.com
- Update to Java 8.0 Service Refresh 6 Fix Pack 10 [bsc#1172277, bsc#1169511]
    CVE-2020-2805 CVE-2020-2803 CVE-2020-2830 CVE-2020-2781 CVE-2020-2800
    CVE-2020-2757 CVE-2020-2756 CVE-2020-2755 CVE-2020-2754 CVE-2019-2949
  * Security:
  - ADD RSA PSS SUPPORT TO IBMPKCS11IMPL
  - UPDATES TO IBMJCEPLUS AND IBMJCE
  * Java Virtual Machine:
  - ASSERTION FAILURE IN JCLEXCEPTION.C
  - FIX THE LENGTH OF THE CLASS NAME IN VERIFYING THE QUALIFIED CLASS NAME
  - MEMORY_COLLECTION_THRESH OLD_EXCEEDED NOTIFICATION FOR MEMORYPOOLMXBEAN
    IS TRIGGERED MORE THAN EXPECTED
  * JIT Compiler:
  - CRASH IN JIT COMPILED CODE ON SYSTEMZ
  - FAILURE TO COMPILE LARGE METHODS CONTAINING CALLS TO JNI ROUTINES
  - RARE CRASH READING AN ADDRESS JUST BEYOND THE END OF THE JAVA HEAP
- Update to Java 8.0 Service Refresh 6 Fix Pack 7
  * Java Virtual Machine:
  - SLOW JVM STARTUP SPEED ON A FULL SHARED CACHE
  * JIT Compiler:
  - GPF DURING COMPILATION WHILE PROCESSING CFG
  - JAVA JIT: NEW OPTION TO PREVENT ALIASING PRIMITIVE BOX CLASSES FINAL FIELDS
  - UNEXPECTED BEHAVIOUR: HASH MAP RETURNING INCORRECT HASH CODE VALUE AFTER
    CERTAIN ITERATION ON LINUX ON Z
  - UNEXPECTED NPE CAUSED BY AN INCORRECT JIT COMPILER OPTIMIZATION
  * Security:
  - KEYTOOL IS UNABLE TO LIST ALL THE CERTIFICATES IN A PKCS12 KEYSTORE IN
    CERTAIN CONDITIONS
  - NULLPOINTEREXCEPTION THROWN FROM X509CERTIMPL.GETISSUERKE YIDENTIFIER
  - WEBSPHERE FAILS TO SUCCESSFULLY VALIDATE A CERTIFICATE CHAIN USING THE
    CERTPATH SECURITY COMPONENT
* Thu Mar 12 2020 pmonrealgonzalez@suse.com
- Update to Java 8.0 Service Refresh 6 Fix Pack 6 [bsc#1160968]
  * Security:
    IJ22978 FIX SECURITY VULNERABILITY CVE-2020-2654
    IJ22143 JAVA.IO.IOEXCEPTION: SEQUENCE TAG ERROR THROWN WHILE
    USING CERTPATH TO VALIDATE A CERTIFICATE CHAIN
  * Class Libraries:
    IJ22726 REGRESSION IN APPLET STARTUP TIME ON IE BROSWERS
  * Java Virtual Machine:
    IJ21943 MISSING PARAMETERS TO EXCEPTION MESSAGE
  * XML:
    IJ22335 THE XSD DATATYPE GYEAR INCORRECTLY ALLOWS VALUES WITH
    LESS THAN 4 DIGITS
* Fri Feb  7 2020 pmonrealgonzalez@suse.com
- Update to Java 8.0 Service Refresh 6 Fix Pack 5 [bsc#1162972, bsc#1160968]
  * Security Fixes:
    CVE-2020-2583 CVE-2020-2593 CVE-2020-2604 CVE-2020-2659
    CVE-2019-4732
    IJ21985 IBMJCE PROVIDER IS UNABLE TO BUILD A CERTIFICATE CHAIN
    WHEN A PKCS12 KEYSTORE HAS BOTH GOOD AND BAD INTERMEDIATE
    CERTIFICATES
    IJ21208 KDB to JKS keystore conversion creates JKS keystore with
    broken certificate chain, regression introduced in
    CMSProvider 2.63
    IJ21616 THE SECURITY PROPERTY 'JDK.CERTPATH.DISABLED ALGORITHMS' IS
    MISTAKENLY BEING USED TO FILTER JAR SIGNING ALGORITHMS
  * Class Libraries:
    IJ22359 HANG IN JAVA_JAVA_NET_SOCKETINPUTSTREAM_SOCKETREAD0 EVEN
    WHEN TIMEOUT IS SET
    IJ22350 JAVA 7 AND JAVA 8 NOT WORKING WELL WITH TRADITIONAL/SIMPLIFIED
    CHINESE EDITION OF WINDOWS CLIENT SYSTEM
    IJ22064 JAVA OUT OF MEMORY (HEAP SPACE) JAVA V8 IN Z/OS WITH
    STRINGS OR CHAR ARRAYS
    IJ22142 JAXB XML VALIDATION FAILS ON IBM JDK >= 8.0.5.15
    IJ22141 PERFORMANCE ISSUE ON JAVA 8 WITH FDLIBM LIBRARY IN AIX
    IJ22351 SUN.NIO.CS.EXT.IBM1390$D ECODER OBJECTS CONSUMED JAVA HEAP
    FOR JAVA8
    IJ22337 THE NAME OF THE REPUBLIC OF BELARUS IN THE RUSSIAN LOCALE
    INCONSISTENT WITH CLDR
    IJ22349 UPDATE TIMEZONE INFORMATION TO TZDATA2019C
  * Java Virtual Machine:
    IJ20714 A SIGSEGV/GPF IS RECEIVED FROM METHOD RESIZELOA()
    IJ20379 CRASH OR ASSERTION FAILURE HAPPENED AFTER DECOMPILATION
    WHEN FSD WAS ENABLED
    IJ21959 GARBAGE COLLECTION NOTIFICATION IS NOT EMITTED
    IJ21098 IBM J9 UNBLOCKS SIGNALS BY DEFAULT
    IJ21009 INCREASED RESPONSE TIME AND HIGH CPU UNDER BALANCED GC POLICY
    IJ21925 RELAX REFERENCE ASSERT AFTER SCAVENGER CLEARING
  * JIT Compiler:
    IJ21488 CRASH DURING JIT COMPILATION
    IJ20441 CRASH IN JVM INTERPRETER AFTER OSR
    IJ20662 INCORRECT RESULTS FOR EXPRESSIONS WITH SHIFTS
    IJ21489 PERFORMANCE REGRESSION WHEN CALLING JNI ON POWER (AIX & LINUX)
    IJ22219 RUNTIME FAILURE IN THE JIT WHEN RUNNING ON Z ARCHITECTURE
    IJ22150 RUNTIME FAILURE IN THE JIT WHEN RUNNING ON Z ARCHITECTURE
  * ORB:
    IX90190 OUTOFMEMORYERROR THROWN FROM CDRREADER.READBYTESFORST RING
* Wed Dec  4 2019 pmonrealgonzalez@suse.com
- Update to Java 8.0 Service Refresh 6 [bsc#1158442, bsc#1154212]
  * Security fixes:
    CVE-2019-2933 CVE-2019-2945 CVE-2019-2958
    CVE-2019-2962 CVE-2019-2964 CVE-2019-2975
    CVE-2019-2978 CVE-2019-2983 CVE-2019-2988
    CVE-2019-2989 CVE-2019-2992 CVE-2019-2996
    CVE-2019-2999 CVE-2019-2973 CVE-2019-2981
    CVE-2019-17631
  * Security:
    IJ18632 'NO SUCH ALGORITHM: 1.2.840.113549.2.X WHILE STORING OR RETRIEVING HMACSHAX USING A PKCS12 KEY STORE
    IJ19796 ADD PIECEMEAL SHA*WITHDSA SIGNATURE CAPABILITY TO THE IBMPKCS11IMPL CRYPTO PROVIDER
    IJ19669 NULLPOINTEREXCEPTION OCCURS WHEN READING AN EMPTY PKCS12 KEYSTORE USING JAVA
    IJ19242 CERTPATH UPDATES IN SUPPORT OF THE JSSE TLS 1.3 PROTOCOL
    IJ18349 IBMJCE ISSUE#44 ADD PKCS12 KEYSTORE ISSUER SUBJECT KEY ID CHECKING TO CERT CHAIN PROCESSING
    IJ18830 MEMORY GROWTH IN IBMJCEPLUS PROVIDER WHILE USING AESGCM IN TLS1.2 PROTOCOL
    IJ19243 PKCS UPDATES IN SUPPORT OF THE JSSE TLS 1.3 PROTOCOL
    IJ20639 SUPPORT FOR NEW ALGORITHMS ADDED TO IBMJCEPLUS AND IBMJCEPLUSFIPS PROVIDERS
    IJ18572 UPDATE CMSPROVIDER FOR IBMJCEPLUS
    IJ18573 UPDATE IKEYMAN FOR IBMJCEPLUS, PKCS12 KEYSTORE CORRUPTED AFTER USING IKEYMAN
  * Class libraries:
    IJ21181 3 JCK CASES FAILED IN IBM I PLATFORM ABOUT AWT
    IJ15709 JAVA LAUNCHER FAILS TO LOAD IF LOADED WITH AN EXPLICIT LOADER
    IJ20939 PROBLEM WITH SECRET (SYMMETRIC) KEY ALGORITHM IN IBMJCEPLUS
    IJ20980 UPDATE TIMEZONE INFORMATION TO TZDATA2019A AND 2019B
  * Java Virtual Machine
    IJ19657 ASSERTION FAILURE FROM STANDARDACCESSBARRIER.CP P:767
    IJ20612 CRASH FROM RUNCALLINMETHOD() RELATED TO SHARED CLASSES CACHE
    IJ20908 SEGMENTATION ERROR FROM LIBJ9VM29
    IJ20395 SEGV READING DATA VIA UNSAFE.GETBYTE()
  * JIT Compiler
    IJ20311 A SIGFPE ERROR IS RAISED IN JAVA JIT COMPILED METHOD USING DATA ACCESS ACCELERATOR LIBRARY
    IJ20441 CRASH IN JVM INTERPRETER AFTER OSR
    IJ19899 CRASH WHILE THROWING A CLASSCASTEXCEPTION
    IJ21225 INFINITELOOP ON STATIC FINAL FIELD MODIFICATION
    IJ18450 JAVA JIT - CRASH IN USEREGISTER() ON POWER HARDWARE
    IJ20528 NULLPOINTEREXCEPTION OR SEGMENTATION FAULT FOR METHOD CALL TO OBJECT OF A PRIMITIVE WRAPPER TYPE
  * z/OS Extentions
    PH17464 High CPU when using Elliptic Curve Ciphers (ECC) and the IBMJCECCA and IBMJSSE2 Providers
    PH19449 IBMJCEHYBRID DOES NOT FAILOVER BECAUSE SIGNATURE EXCEEDS BLOCKSIZE OF 2048
* Tue Oct  1 2019 pmonrealgonzalez@suse.com
- Update to Java 8.0 Service Refresh 5 Fix Pack 41 [bsc#1143080]
  * JIT compiler crash: Remove implicit sign extension assumptions
    from iRegStore evaluator (https://github.com/eclipse/omr/pull/4103)
* Fri Aug 23 2019 pmonrealgonzalez@suse.com
- Update to Java 8.0 Service Refresh 5 Fix Pack 40 [bsc#1147021]
  * Security fixes:
    CVE-2019-11772 (bsc#1147021) CVE-2019-11775 (bsc#1147021) CVE-2019-4473 (bsc#1147021)
    CVE-2019-11771 (bsc#1147021) CVE-2019-7317 (bsc#1141780) CVE-2019-2769 (bsc#1141783)
    CVE-2019-2762 (bsc#1141782) CVE-2019-2816 (bsc#1141785) CVE-2019-2766 (bsc#1141789)
    CVE-2019-2786 (bsc#1141787)
    IJ17282 IBMJCEPLUS NAME SPACE CHANGE FOR GSKIT
    IJ17055 JSSE2 MEMORY LEAK ON COM.IBM.JSSE2.EXT.ALPNJS SEEXT
    IJ17640 OPTIMIZE SHA PERFORMANCE
  * Class Libraries:
    IJ18126 JAVA.LANG.INTERNALERROR: SPAWNP FAILURE, ERRNO=3450
    IJ14454 REPLACE HARMONY IMPLEMENTATION OF JDWP WITH OPENJDK JDWP IMPLEMENTATION
    IJ18131 UPDATE TIMEZONE INFORMATION TO TZDATA2018I
  * JIT Compiler:
    IJ17054 JAVA JIT ON POWER: CRASH IN FREEBESTREGISTER()
    IJ17817 PROBLEMS CALLING NON-XPLINK NATIVE ON Z/OS 31BIT
    IJ18244 SEGMENTATION FAULT WHILE RUNNING JIT COMPILED CODE
  * ORB:
    IX90189 HANDLE SCHEMA USE-CASE SCENARIO FOR APAR IX90188
- Update to Java 8.0 Service Refresh 5 Fix Pack 37
  * Class Libraries:
    IJ16550 CP1386 CTRL CHARS COMPATIBILITY ISSUE BETWEEN JAVA AND DB2
    IJ15675 THE FONTMANAGER LIBRARY NEEDS TO BE LINKED AGAINST THE AWT HEADLESS LIBRARY
  * Java Virtual Machine:
    IJ15979 DUMP EVENT 'TRACEASSERT' (00080000) RECEIVED WHEN JNI CHECKING IS ENABLED
    IJ16376 SEGMENTATION ERROR WHEN INVOKING JNI METHOD JAVA.LANG.ACCESS.GETCONS TANTPOOL()
  * JIT Compiler:
    IJ16221 GC ASSERTION WHEN RUNNING METRONOME
    IJ16118 HANG WITH ALL THREADS WAITING
- Update to Java 8.0 Service Refresh 5 Fix Pack 36
  * JIT Compiler:
    IJ15764 CRASH DURING JIT COMPILATION
    IJ15793 CRASH DURING JIT COMPILATION
    IJ16011 INCORRECT RESULTS AFTER METHOD IS JIT COMPILED
    IJ15826 INTERMITTENT CRASH IN JAVA JIT COMPILER
  * z/OS Extentions:
    PH11921 JZOS PDS MEMBER STATISTICS THROWS AN EXCEPTION ON INVALID ISPF DATA
    PH11870 JZOS SUPPORT OF Z/OS CODE PAGES
* Thu May  9 2019 pmonrealgonzalez@suse.com
- Update to Java 8.0 Service Refresh 5 Fix Pack 35 [bsc#1134718]
  * Security fixes:
    CVE-2019-10245 (bsc#1134718) CVE-2019-2698 (bsc#1132729)
    CVE-2019-2697 (bsc#1132734) CVE-2019-2602 (bsc#1132728)
    CVE-2019-2684 (bsc#1132732)
* Wed Mar  6 2019 pmonrealgonzalez@suse.com
- Update to Java 8.0 Service Refresh 5 Fix Pack 30
  * Security fixes:
    CVE-2018-12547 CVE-2018-12549 CVE-2018-1890 (bsc#1128158)
    CVE-2018-11212 (bsc#1122299) CVE-2019-2426 CVE-2019-2449 (bsc#1122292)
    CVE-2019-2422 (bsc#1122293)
- Update to Java 8.0 Service Refresh 5 Fix Pack 27
  * Class Libraries:
    IJ12021 IBM JRE FAILS TO CLOSE THE FILE DESCRIPTORS RELATED TO
    ASYNCHRONOUSSERVERSOCKET CHANNEL OBJECT AFTER APPLYING
  FIX FOR APAR OA3350
  * Java Virtual Machine:
    IJ11480 CRASH IN FFISYS CALL IN ZOS
    IJ12137 FAILED TO START JVM WITH SPECIAL HEAP CONFIGURATION ON NUMA CAPABLE PLATFORM
  * JIT Compiler:
    IJ11315 ABEND IN TR_OSRCOMPILATIONDATA::W RITEMETADATA ON Z/OS
    IJ12196 ARRAYINDEXOUTOFBOUNDS EXCEPTION OR OTHER SYMPTOMS
    IJ11619 CONCURRENT SCAVENGE HANG WHEN GC DOES NOT MOVE OBJECT IN J9READBARRIER
    IJ11620 CRASH IN TR_J9VMBASE::GETRESOLVED VIRTUALMETHOD
    IJ12136 HIGH 32-BIT OF LONG VALUE IS CLOBBERED
    IJ12156 INCORRECT FLOATING POINT RESULT ON X86 MACHINES SUPPORTING AVX
    IJ12158 INCORRECT METHOD EXECUTION AFTER HCR METHOD REDEFINITION
    IJ12157 INCORRECT NULL POINTER EXCEPTION THROWN
    IJ11368 JAVA JIT PPC: CRASH IN JIT COMPILED CODE ON PPC MACHINES
    IJ12109 PERFORMANCE REGRESSION OF ABOUT 2%%-6%%
    IJ12097 WRONG RESULT FROM STRING.INDEXOF AND STRING.LASTINDEXOF
  * XML:
    IJ11730 XLXP XML PARSER: INTRODUCE SYSTEM PROPERTY TO ENABLE USE OF PLATFORM ENCODING
* Wed Dec 12 2018 pmonrealgonzalez@suse.com
- Update to Java 8.0 Service Refresh 5 Fix Pack 26 [bsc#1119213]
  * JIT Compiler
    IJ11150 AUTOSIMD BADILOP ASSERTION
    IJ10792 CRASH DURING COMPILATION WITH STD::BAD_ALLOC ON X86
    IJ11151 CRASH IN JIT COMPILATION IN TR_CLASSLOOKAHEAD::EXAMI NENODE ON ALL PLATFORMS
    IJ10928 INTERMITTENT CRASH IN THE JAVA JIT COMPILER RUNNING ON Z/OS
    IJ11731 JAVA FAILS WITH SIGSEGV WHEN -XJIT:DISABLEZ10 OPTION IS SUPPLIED
    IJ11621 X86 CRASH WITH GC ASSERTION RUNNING JIT COMPILED METHOD
  * Reliability and Serviceability
    IJ10763 TRACEFORMAT CAN MISINTERPRET EVENTS CONTAINING CERTAIN STRINGS
* Mon Nov 19 2018 pmonrealgonzalez@suse.com
- Update to Java 8.0 Service Refresh 5 Fix Pack 25 [bsc#1116574]
  * Class Libraries:
    IJ10934 CVE-2018-13785
    IJ10935 CVE-2018-3136
    IJ10895 CVE-2018-3139
    IJ10932 CVE-2018-3149
    IJ10894 CVE-2018-3180
    IJ10930 CVE-2018-3183
    IJ10933 CVE-2018-3214
    IJ09315 FLOATING POINT EXCEPTION FROM JAVA.TEXT.DECIMALFORMAT. FORMAT
    IJ09088 INTRODUCING A NEW PROPERTY FOR TURKEY TIMEZONE FOR PRODUCTS NOT IDENTIFYING TRT
    IJ10800 REMOVE EXPIRING ROOT CERTIFICATES IN IBM JDK'S CACERTS.
    IJ10566 SUPPORT EBCDIC CODE PAGE IBM-274 - BELGIUM EBCDIC
  * Java Virtual Machine
    IJ08730 APPLICATION SIGNAL HANDLER NOT INVOKED FOR SIGABRT
    IJ10453 ASSERTION FAILURE AT CLASSPATHITEM.CPP
    IJ09574 CLASSLOADER DEFINED THROUGH SYSTEM PROPERTY 'JAVA.SYSTEM.CLASS.LOADE R' IS NOT HONORED.
    IJ10931 CVE-2018-3169
    IJ10618 GPU SORT: UNSPECIFIED LAUNCH FAILURE
    IJ10619 INCORRECT ILLEGALARGUMENTEXCEPTION BECAUSE OBJECT IS NOT AN INSTANCE OF DECLARING CLASS ON REFLECTIVE INVOCATION
    IJ10135 JVM HUNG IN GARBAGECOLLECTORMXBEAN.G ETLASTGCINFO() API
    IJ10680 RECURRENT ABORTED SCAVENGE
  * ORB
    IX90187 CLIENTREQUESTIMPL.REINVO KE FAILS WITH JAVA.LANG.INDEXOUTOFBOUN DSEXCEPTION
  * Reliability and Serviceability
    IJ09600 DTFJ AND JDMPVIEW FAIL TO PARSE WIDE REGISTER VALUES
  * Security
    IJ10492 'EC KEYSIZE < 384' IS NOT HONORED USING THE 'JDK.TLS.DISABLEDALGORIT HMS' SECURITY PROPERTY
    IJ10310 ADD NULL CHECKING ON THE ENCRYPTION TYPES LIST TO CREDENTIALS.GETDEFAULTNA TIVECREDS() METHOD
    IJ10491 AES/GCM CIPHER - AAD NOT RESET TO UN-INIT STATE AFTER DOFINAL( ) AND INIT( )
    IJ08442 HTTP PUBLIC KEY PINNING FINGERPRINT,PROBLEM WITH CONVERTING TO JKS KEYSTORE
    IJ09107 IBMPKCS11IMPL CRYPTO PROVIDER - INTERMITTENT ERROR WITH SECP521R1 SIGNATURE ON Z/OS
    IJ10136 IBMPKCS11IMPL - INTERMITTENT ERROR WITH SECP521R1 SIG ON Z/OS AND Z/LINUX
    IJ08530 IBMPKCS11IMPL PROVIDER USES THE WRONG RSA CIPHER MECHANISM FOR THE RSA/ECB/PKCS1PADDING CIPHER
    IJ08723 JAAS THROWS A 'ARRAY INDEX OUT OF RANGE' EXCEPTION
    IJ08704 THE SECURITY PROPERTY 'JDK.CERTPATH.DISABLEDAL GORITHMS' IS MISTAKENLY BEING USED TO FILTER JAR SIGNING ALGORITHMS
  * z/OS Extentions
    PH03889 ADD SUPPORT FOR TRY-WITH-RESOURCES TO COM.IBM.JZOS.ENQUEUE
    PH03414 ROLLOVER FROM SYE TO SAE FOR ICSF REASON CODE 3059
    PH04008 ZERTJSSE - Z SYSTEMS ENCRYPTION READINESS TOOL (ZERT) NEW SUPPORT IN THE Z/OS JAVA SDK
- Update to Java 8.0 Service Refresh 5 Fix Pack 22
  * Java Virtual Machine
    IJ09139 CUDA4J NOT AVAILABLE ON ALL PLATFORMS
  * JIT Compiler
    IJ09089 CRASH DURING COMPILATION IN USEREGISTER ON X86-32
    IJ08655 FLOATING POINT ERROR (SIGFPE) IN ZJ9SYM1 OR ANY VM/JIT MODULE ON AN INSTRUCTION FOLLOWING A VECTOR INSTRUCTION
    IJ08850 CRASH IN ARRAYLIST$ITR.NEXT()
    IJ09601 JVM CRASHES ON A SIGBUS SIGNAL WHEN ACCESSING A DIRECTBYTEBUFFER
  * z/OS Extentions
    PH02999 JZOS data management classes accept dataset names in code pages supported by z/OS system services
    PH01244 OUTPUT BUFFER TOO SHORT FOR GCM MODE ENCRYPTION USING IBMJCEHYBRID
- Update to Java 8.0 Service Refresh 5 Fix Pack 21
  * Class Libraries
    IJ08569 JAVA.IO.IOEXCEPTION OCCURS WHEN A FILECHANNEL IS BIGGER THAN 2GB ON AIX PLATFORM
    IJ08570 JAVA.LANG.UNSATISFIEDLIN KERROR WITH JAVA OPTION -DSUN.JAVA2D.CMM=SUN.JAV A2D.CMM.KCMS.KCMSSERVICE
    PROVIDER ON AIX PLATFORM
  * Java Virtual Machine
    IJ08001 30%% THROUGHPUT DROP FOR CERTAIN SYNCHRONIZATION WORKLOADS
    IJ07997 TRACEASSERT IN GARBAGE COLLECTOR(MEMORYSUBSPACE)
  * JIT Compiler
    IJ08503 ASSERTION IS HIT DUE TO UNEXPECTED STACK HEIGHT IN DEBUGGING MODE
    IJ08375 CRASH DURING HARDWARE GENERATED GUARDED STORAGE EVENT WITHIN A TRANSACTIONAL EXECUTION REGION WHEN
    RUNNING WITH -XGC:CONCURRENTS
    IJ08205 CRASH WHILE COMPILING
    IJ09575 INCORRECT RESULT WHEN USING JAVA.LANG.MATH.MIN OR MAX ON 31-BIT JVM
    IJ07886 INCORRECT CALUCATIONS WHEN USING NUMBERFORMAT.FORMAT() AND BIGDECIMAL.{FLOAT/DOUBLE }VALUE()
* Mon Aug 13 2018 tchvatal@suse.com
- Version update to 8.0.5.20 [bsc#1104668]
  * Various JIT/JVM crash fixes
  * Security fixes:
    CVE-2018-2952 CVE-2018-2940 CVE-2018-2973 CVE-2018-2964
    CVE-2016-0705 CVE-2017-3732 CVE-2017-3736 CVE-2018-1517
    CVE-2018-1656 CVE-2018-12539
* Tue May 15 2018 pmonrealgonzalez@suse.com
- Version update to 8.0.5.15 [bsc#1093311, bsc#1085449]
  * Security fixes:
    CVE-2018-2826 CVE-2018-2825 CVE-2018-2814 CVE-2018-2794
    CVE-2018-2783 CVE-2018-2799 CVE-2018-2798 CVE-2018-2797
    CVE-2018-2796 CVE-2018-2795 CVE-2018-2800 CVE-2018-2790
    CVE-2018-1417
* Wed May  9 2018 pmonrealgonzalez@suse.com
- Removed translations in the java-1_8_0-ibm-devel-32bit package
  as they conflict with those in java-1_8_0-ibm-devel.
* Tue Apr 17 2018 tchvatal@suse.com
- Version update to 8.0.5.11 [bsc#1089841]
  * IJ03328	Class Libraries		JAVA PLUGIN AND WEBSTART THROW A JAVA.LANG.STACKOVERFLOWE RROR EXCEPTION WITH IBM JAVA 1.8 ON UNIX PLATFORM
  * IJ03117	Class Libraries		UPDATE CACERTS TO INCLUDE ROOT CERTIFICATES FROM LETSENCRYPT AND IDENTRUST
  * IJ04429	Java Virtual Machine		A GPF EVENT IS THROWN FROM JAVA_COM_IBM_JIT_JITHELP ERS_GETBACKFILLOFFSETFRO MJ9CLASS64 OR A NULLPOINTEREXCEPTION IS THROWN
  * IJ04647	Java Virtual Machine		AVOID OPENING THE SHARED CACHE MEMORY CONTROL FILE TO RETRIEVE TOTAL CACHE SIZE FOR NON-PERSISTENT CACHE
  * IJ03676	Java Virtual Machine		JVM HUNG WHILE SHUTTING DOWN
  * IJ04706	Java Virtual Machine		NPE AT JAVA.SECURITY.ACCESSCONT ROLCONTEXT.HASHCODE()
  * IJ05407	JIT Compiler		CRASH IN JIT MODULE WHILE RUNNING JAVA 8SR5 X86-32 HARDWARE
  * IJ04875	JIT Compiler		JAVA JIT: CRASH IN JIT LIBRARY FUNCTION FINDCLASSINFO()
  * IJ04409	JIT Compiler		JAVA JIT: LONG GC PAUSE TIMES WHEN UNLOADING CLASSES
  * IJ04249	JIT Compiler		JAVA JIT PPC - CRASH EXECUTING SOME JAVA.UTIL.CONCURRENT.ATO MIC.ATOMIC* ROUTINES
  * IJ03854	JIT Compiler		JVM INFO MESSAGE APPEARS IN STDOUT
  * IJ03969	Security		IBMPKCS11IMPL CRYPTO PROVIDER - DEBUG TRACING ERROR IN THE PKCS11KEYSTORE CLASS
  * PI95513	z/OS Extentions		JZOS ZFILE.READJFCB MEMORY LEAK
* Tue Mar 20 2018 pmonrealgonzalez@suse.com
- Renamed the update-alternatives link names for the different
  policy options to avoid collisions [bsc#1085018]
  * Available options:
  - jce_1.8.0_ibm_unlimited_local_policy [default]
  - jce_1.8.0_ibm_unlimited_us_export_policy
  - jce_1.8.0_ibm_limited_local_policy
  - jce_1.8.0_ibm_limited_us_export_policy
* Fri Mar 16 2018 pmonrealgonzalez@suse.com
- Fixed priorities of alternatives [bsc#1085018]
* Wed Mar 14 2018 pmonrealgonzalez@suse.com
- Fixed symlinks to policy files on update [bsc#1085018]
* Tue Feb 27 2018 pmonrealgonzalez@suse.com
- Removed java-1_8_0-ibm-alsa and java-1_8_0-ibm-plugin entries in
  baselibs.conf due to errors in osc source_validator
* Mon Feb 26 2018 pmonrealgonzalez@suse.com
- Version update to 8.0.5.10 [bsc#1082810]
  * Security fixes:
    CVE-2018-2639 CVE-2018-2638 CVE-2018-2633 CVE-2018-2637
    CVE-2018-2634 CVE-2018-2582 CVE-2018-2641 CVE-2018-2618
    CVE-2018-2603 CVE-2018-2599 CVE-2018-2602 CVE-2018-2678
    CVE-2018-2677 CVE-2018-2663 CVE-2018-2588 CVE-2018-2579
  * Defect fixes:
  - IJ02608 Class Libraries: Change of namespace definitions with
    handlers that implement javax.xml.ws.handler.soap.soaphandler
  - IJ04280 Class Libraries: Deploy Upgrade to Oracle level 8u161-b12
  - IJ03390 Class Libraries: JCL Upgrade to Oracle level 8u161-b12
  - IJ04001 Class Libraries: Performance improvement with child
    process on AIX
  - IJ04281 Class Libraries: Startup time increase after applying
    apar IV96905
  - IJ03822 Class Libraries: Update timezone information to tzdata2017c
  - IJ03440 Java Virtual Machine: Assertion failure during class creation
  - IJ03717 Java Virtual Machine: Assertion for gencon with concurrent
    scavenger on ZOS64
  - IJ03513 Java Virtual Machine: Assertion in concurrent scavenger if
    initial heap memory size -Xms is set too low
  - IJ03994 Java Virtual Machine: Class.getmethods() does not return
    all methods
  - IJ03413 Java Virtual Machine: Hang creating thread after redefining
    classes
  - IJ03852 Java Virtual Machine: ICH408I message when groupaccess is
    specified with -xshareclasses
  - IJ03716 Java Virtual Machine: java/lang/linkageerror from
    sun/misc/unsafe.definean onymousclass()
  - IJ03116 Java Virtual Machine: java.fullversion string contains an
    extra space
  - IJ03347 Java Virtual Machine: java.lang.IllegalStateException in
    related class MemoryMXBean
  - IJ03878 Java Virtual Machine: java.lang.StackOverflowError is thrown
    when custom security manager in place
  - IJ03605 Java Virtual Machine: Legacy security for com.ibm.jvm.dump,
    trace, log was not enabled by default
  - IJ04248 JIT Compiler: ArrayIndexOutOfBoundsException is thrown when
    converting BigDecimal to String
  - IJ04250 JIT Compiler: Assertion failure with concurrentScavenge on Z14
  - IJ03606 JIT Compiler: Java crashes with -version
  - IJ04251 JIT Compiler: JIT compiled method that takes advantage of
    AutoSIMD produces an incorrect result on x86
  - IJ03854 JIT Compiler: JVM info message appears in stdout
  - IJ03607 JIT Compiler: Result String contains a redundant dot when
    converted from BigDecimal with 0 on all platforms
  - IX90185 ORB: Upgrade ibmcfw.jar to version O1800.01
  - IJ03715 Security: Add additional support for the IBMJCEPlus provider,
    add support for new IBMJCEPlusFIPS provider
  - IJ03800 Security: A fix in CMS provider for KDB integrity
  - IJ04282 Security: Change in location and default of jurisdiction
    policy files
  - IJ03853 Security: IBMCAC provider does not support SHA224
  - IJ02679 Security: IBMPKCS11Impl - Bad sessions are being allocated
    internally
  - IJ02706 Security: IBMPKCS11Impl - Bad sessions are being allocated
    internally
  - IJ03552 Security: IBMPKCS11Impl - Config file problem with the slot
    specification attribute
  - IJ01901 Security: IBMPKCS11Impl - SecureRandom.setSeed() exception
  - IJ03801 Security: Issue with same DN certs, iKeyman GUI error with
    stash, JKS Chain issue and JVM argument parse issue with iKeyman
  - IJ03256 Security: javax.security.auth.Subject.toString() throws NPE
  - PI93233 z/OS Extentions: Cipher.doFinal() fails when using
    AES/GCM/nopadding with AAD data of 13 bytes and a block size
  of 4081 to 4096
  * Fixes in 8.0.5.7:
  - IJ02605 Class Libraries: Update IBM-1371 charset with new specification
    support
  - IJ02541 Java Virtual Machine: Assertions in GC when jvmti runs with
    Concurrent Scavenger
  - IJ02443 Java Virtual Machine: Committed eden region size is bigger than
    maximum eden region size
  - IJ02378 Java Virtual Machine: Existing signal action for SIG_IGN/SIG_DFL
    is not detected properly
  - IJ02758 JIT Compiler: Crash in JIT module during method compilation
  - IJ02733 JIT Compiler: Crash in jit module when compiling in non-default
    configuration
  * Fixes in 8.0.5.6:
  - IJ02283 Java Virtual Machine: IllegalAccessException due to a missing
    access check for the same class in MethodHandle apis
  - IJ02082 Java Virtual Machine: The default value for class unloading kick
    off threshold is not set
  - IJ02018 JIT Compiler: Crash or assertion while attempting to acquire
    VM access
  - IJ02284 JIT Compiler: Division by zero in JIT compiler
  - IV88941 JIT Compiler: JIT compiler takes far too long to compile a
    method
  - IJ02285 JIT Compiler: Performance degradation during class unloading in
    Java 8 SR5
* Wed Nov 29 2017 pmonrealgonzalez@suse.com
- Version update to 8.0.5.5 [bsc#1070162]
  * CVE-2017-10346 CVE-2017-10285 CVE-2017-10388 CVE-2017-10309
    CVE-2017-10356 CVE-2017-10293 CVE-2016-9841  CVE-2016-10165
    CVE-2017-10355 CVE-2017-10357 CVE-2017-10348 CVE-2017-10349
    CVE-2017-10347 CVE-2017-10350 CVE-2017-10281 CVE-2017-10295
    CVE-2017-10345
* Mon Sep 25 2017 pmonrealgonzalez@suse.com
- Fixed jpackage-java-1_8_0-ibm-webstart.desktop file to allow
  Java jnlp files run from Firefox. [bsc#1057460, bsc#1076390]
* Fri Sep 22 2017 pmonrealgonzalez@suse.com
- Version update to 8.0-5.0 [bsc#1059808, fate#322435]
  * New features/enhancements.
  - IV99474 Security: Add support for the IBMJCEPlus provider
  * Fixes:
  - IV98234 Java JIT: Compiler time crash in analyzeexitedges()
  - IV99877 Class Libraries: Including Oracle update number in
    java -version ouput
  - IV99875 Class Libraries: Including Oracle update number in
    the release file
  - IV99598 Class Libraries: java.lang.reflect.Method.toGenericString()
    produce different output for generics which takes
  primitive array types
  - IV99876 Class Libraries: Update Xscmx description in IBM -X
    help output
  - IV99596 JVM: Calling Thread.getStackTrace on the current
    thread returns extra stack frames
  - IV99856 JVM: Crash during JVM shutdown
  - IV98626 JVM: Crash in JIT
  - IV96569 JVM: Extra 2GB page allocated for the object heap
    on z/OS or zLinux
  - IV99768 JVM: GC assertion in MM_ParallelTask or
    MM_ParallelScavengeTask after scavenger backout
  - IV81824 JVM: java.lang.Class.getMethods() does not return
    all interface methods
  - IV99741 JVM: Java synchronization improvements
  - IV99824 JVM: Java VM fails due to assertion in stringtable.cpp
  - IV99784 JVM: JVMTI API SetEventNotificationMode() fails for
    event type JVMTI_EVENT_RESOURCE_EXHAUSTED
  - IV93219 JVM: MethodHandle asType and invoke throw incorrect
    exception when return type doesn't match
  - IV99192 JVM: Method resolution reports default method
    conflict on virtual invocations
  - IV99769 JVM: Missing package private class
    java.lang.AbstractStringBuilder during verification
  - IV96433 JVM: Performance regression in JVMTI class redefinition
  - IV99821 JVM: System core file is missing when the Linux core
    file (not command) pattern contains %%c and user's
  core file size limit is 0
  - IV99770 JVM: The VerifyError message contained an incorrect
    type to be matched for 'aastore' bytecodes
  - IV91274 JVM: Unexpected IllegalArgumentException requesting a
    BufferPoolMXBean by name
  - IV99742 JVM: Unnecessary message printed out when resetting
    a shared cache
  - IV99771 JVM: Verifier incorrectly rejected uses of uninitialized
    objects in 'monitorenter/monitorexit' bytecodes
  - IV99754 JVM: VM crashes when printing trace points
  - IV98212 Java JIT: Assertion in GC
  - IV99215 Java JIT: Crash during JIT compilation in Java 8
  - IV99780 Java JIT: Crashes in JIT-compiled java code
    containing loops
  - IV99783 Java JIT: Crashes in JIT-compiled java code on power platforms
  - IV99785 Java JIT: Crash in DAA API compiled code
  - IV99779 Java JIT: GC assertion when walking a JIT compiled frame
  - IV99778 Java JIT: Incorrect index used when accessing array
  - IV99782 Java JIT: InvocationTargetException in JSR 292 Java code
  - IV98001 Java JIT: ompiler crash
  - IV99693 Java JIT: Compiler crash in OSR processing during inlining
  - IV97890 Java JIT: Compiler problem handling empty control flow block
  - IV97950 Java JIT: JVM crashes in MethodHandle implementation
  - IV91208 Reliability and Serviceability: Crash calling
    com.ibm.jvm.Trace.registerApplication()
  - IV99823 Reliability and Serviceability: Phd files may be incomplete
    when using the balanced garbage collection policy
  - IJ00042 Build: Define the dependency of libstdc++.so.6 in the
    installer on pppc le
  - IV98625 Security: Connection reset during TLS handshake
  - IV98628 Security: NullPointerException performing SSL
    handshake using Chrome browser
* Mon Aug 14 2017 pmonrealgonzalez@suse.com
- Version update to 8.0-4.10 [bsc#1053431]
  * CVE-2017-10111 CVE-2017-10110 CVE-2017-10107 CVE-2017-10101
    CVE-2017-10096 CVE-2017-10090 CVE-2017-10089 CVE-2017-10087
    CVE-2017-10102 CVE-2017-10116 CVE-2017-10074 CVE-2017-10078
    CVE-2017-10115 CVE-2017-10067 CVE-2017-10125 CVE-2017-10243
    CVE-2017-10109 CVE-2017-10108 CVE-2017-10053 CVE-2017-10105
    CVE-2017-10081
* Mon May 15 2017 tchvatal@suse.com
- Version update to 8.0-4.5 bsc#1038505
  CVE-2016-9840 CVE-2016-9841 CVE-2016-9842 CVE-2016-9843 CVE-2017-1289
  CVE-2017-3509 CVE-2017-3511 CVE-2017-3512 CVE-2017-3514 CVE-2017-3533
  CVE-2017-3539 CVE-2017-3544
* Mon Mar  6 2017 tchvatal@suse.com
- Include also in SLE13 fate#322435
- Version update to 8.0-4.1 bnc#1027038 CVE-2016-2183
* Thu Feb 16 2017 tchvatal@suse.com
- Require the main pkg in post phase of devel bsc#1025506
* Wed Feb  8 2017 tchvatal@suse.com
- Version update to 8.0-4.0 bnc#1024218:
  CVE-2016-5552 CVE-2017-3231 CVE-2017-3241 CVE-2017-3253 CVE-2017-3259
  CVE-2017-3261 CVE-2017-3272 CVE-2017-3289 CVE-2016-2183 CVE-2016-5547
  CVE-2016-5548 CVE-2016-5549 CVE-2017-3252
* Wed Nov 16 2016 tchvatal@suse.com
- Version update to 8.0-3.21 bnc#1009280
  CVE-2016-5568 CVE-2016-5556 CVE-2016-5573 CVE-2016-5597 CVE-2016-5554
  CVE-2016-5542
* Tue Oct 25 2016 tchvatal@suse.com
- Add patch for bnc#992537 provided by IBM
* Fri Aug 12 2016 pjanouch@suse.de
- Version update to 8.0-3.10 bnc#992537:
  CVE-2016-3485 CVE-2016-3511 CVE-2016-3511 CVE-2016-3598
- Add hwkeytool binary for s390x
* Fri Apr 29 2016 pjanouch@suse.de
- IBM Java 80-3.0 released:
  (bnc#977646 bnc#977648 bnc#977650 bsc#979252)
  CVE-2016-0376 CVE-2016-0264 CVE-2016-0363 CVE-2016-3443 CVE-2016-0687
  CVE-2016-0686 CVE-2016-3427 CVE-2016-3449 CVE-2016-3422 CVE-2016-3426
* Tue Feb  9 2016 tchvatal@suse.com
- There is no HtmlConverter and apt provided by jdk8 bnc#965665
* Fri Jan 29 2016 tchvatal@suse.com
- Version update to 8.0-2.10 bnc#963937:
  CVE-2015-5041 CVE-2016-0494 CVE-2016-0483 CVE-2015-8126 CVE-2015-8472
  CVE-2016-0475 CVE-2016-0466 CVE-2016-0402 CVE-2015-7575 CVE-2016-0448
* Thu Jan  7 2016 tchvatal@suse.com
- Move %%_jvmdir/%%sdklnk from main to develpkg for sle10 to avoid hickups
- Move %%_jvmjardir/%%sdkcompatdir from develprj to main for the same
* Fri Jan  1 2016 tchvatal@suse.com
- Move the pre phase to the baselibs.conf too bnc#960402
* Mon Nov 23 2015 tchvatal@suse.com
- Version update to 8.0-2.0 bnc#955131, bsc#929900:
  CVE-2015-4734 CVE-2015-4803 CVE-2015-4805 CVE-2015-4806 CVE-2015-4810
  CVE-2015-4835 CVE-2015-4840 CVE-2015-4842 CVE-2015-4843 CVE-2015-4844
  CVE-2015-4860 CVE-2015-4871 CVE-2015-4872 CVE-2015-4882 CVE-2015-4883
  CVE-2015-4893 CVE-2015-4902 CVE-2015-4903 CVE-2015-4911 CVE-2015-5006
* Thu Aug 13 2015 tchvatal@suse.com
- Regen qa filelists and fix summary to say java8 not java 7.1
* Wed Aug  5 2015 tchvatal@suse.com
- Add backcompat symlinks for sdkdir
- Fix bnc#941939 to provide %%{name} instead of %%{sdklnk} only in
  _jvmprivdir
* Wed Jul 22 2015 tchvatal@suse.com
- Add file %%{_jvmdir}/%%{sdkdir}/jre/lib/jexec.diz
- Version update to 8.0.1.10 bnc#938895:
  CVE-2015-1931  CVE-2015-2638  CVE-2015-4733  CVE-2015-4732  CVE-2015-2590
  CVE-2015-4731  CVE-2015-4760  CVE-2015-4748  CVE-2015-2664  CVE-2015-2632
  CVE-2015-2637  CVE-2015-2619  CVE-2015-2621  CVE-2015-2613  CVE-2015-2601
  CVE-2015-4749  CVE-2015-4000  CVE-2015-4729  CVE-2015-2808  CVE-2015-2625
  CVE-2015-0491  CVE-2015-0459  CVE-2015-0469  CVE-2015-0458  CVE-2015-0480
  CVE-2015-0488  CVE-2015-0486  CVE-2015-0478  CVE-2015-0477  CVE-2015-0204
* Thu Jul  2 2015 tchvatal@suse.com
- Version update to 8.0-1.1 bnc#935540 for the logjam attack
- Lets consider this the point we sattisfy the fate#317988
* Wed Jun 17 2015 tchvatal@suse.com
- Sync spec and baselibs.conf
- Remove obsolete parts of update-alternatives from baselibs.conf
- Do not bother with non-etc-marked-as-conf
- Move plugin desktop/icon to proper subpackage
- Fix fdupes usage and javapackages-tools vs jpackage-utils dependencies
- Drop creation of 0 size xlfd support files as they are never
  regenerated anyway
- Cleanup with spec-cleaner
* Wed Jun  3 2015 tchvatal@suse.com
- Filter out cuda requires/provides as it ain't provided in SUSE
  bnc#931693
* Tue Jun  2 2015 tchvatal@suse.com
- Fix removeing links before update-alternatives run. bnc#931702
* Tue Jun  2 2015 tchvatal@suse.com
- Fix bnc#912434, javaws/plugin stuff should slave plugin update-alternatives
* Tue Jun  2 2015 tchvatal@suse.com
- Fix bnc#912447, use system cacerts
* Mon Jun  1 2015 tchvatal@suse.com
- Add condition for fdupes to build on sle10
* Tue May 19 2015 tchvatal@suse.com
- Remove ppc from plugin archs, seems not to be around this time
* Wed May 13 2015 tchvatal@suse.com
- Drop jdbc subpackage as it is empty
* Wed May 13 2015 tchvatal@suse.com
- No specific i386 stuff for plugin anymore
* Wed May 13 2015 tchvatal@suse.com
- Remove not distributed files jrping and jibvdevinfo java_vm javad.options
- remove jdbc as it seems not distributed anymore
- Add jjs and jdeps as files and %%{_jvmdir}/%%{sdkdir}/jre/lib/tools/ folder
* Wed May 13 2015 tchvatal@suse.com
- Actually deploy installer and use proper rpmlintrc
* Wed May 13 2015 tchvatal@suse.com
- Update baselibs.conf to refference java 1.8.0
* Wed May 13 2015 tchvatal@suse.com
- Rename all stuff to try to accomodate java 1.8.0
* Mon Feb  9 2015 tchvatal@suse.com
- Update to 7.1.2.10 for sec issues bnc#916266 and bnc#916265 CVE-2014-8892 CVE-2014-8891
- javad binary seems to be no more, so remove
* Tue Nov 18 2014 tchvatal@suse.com
- bnc#904889 java 1.7.1_sr1.2 released
- CVE-2014-3065: ** RESERVED ** This candidate has been reserved by an
  organization or individual that will use it when announcing a new security
  problem.  When the candidate has been publicized, the details for this
  candidate will be provided. (bnc#)
- CVE-2014-3566: The SSL protocol 3.0, as used in OpenSSL through 1.0.1i and
  other products, uses nondeterministic CBC padding, which makes it easier for
  man-in-the-middle attackers to obtain cleartext data via a padding-oracle
  attack, aka the "POODLE" issue. (bnc#901223 901254 901277 901748 901757 901759
  901889 901968 902229 902476 902912 903684 903690 903692)
- CVE-2014-6513: Unspecified vulnerability in Oracle Java SE 6u81, 7u67, and
  8u20, and Java SE Embedded 7u60, allows remote attackers to affect
  confidentiality, integrity, and availability via vectors related to AWT.
  (bnc#901239 901242 901246)
- CVE-2014-6456: Unspecified vulnerability in Oracle Java SE 7u67 and 8u20
  allows remote attackers to affect confidentiality, integrity, and
  availability via unknown vectors. (bnc#901239 901242 901246)
- CVE-2014-6503: Unspecified vulnerability in Oracle Java SE 6u81, 7u67, and
  8u20 allows remote attackers to affect confidentiality, integrity, and
  availability via unknown vectors related to Deployment, a different
  vulnerability than CVE-2014-4288, CVE-2014-6493, and CVE-2014-6532. (bnc#901239
  901242 901246)
- CVE-2014-6532: Unspecified vulnerability in Oracle Java SE 6u81, 7u67, and
  8u20 allows remote attackers to affect confidentiality, integrity, and
  availability via unknown vectors related to Deployment, a different
  vulnerability than CVE-2014-4288, CVE-2014-6493, and CVE-2014-6503. (bnc#901239
  901242 901246)
- CVE-2014-4288: Unspecified vulnerability in Oracle Java SE 6u81, 7u67, and
  8u20 allows remote attackers to affect confidentiality, integrity, and
  availability via unknown vectors related to Deployment, a different
  vulnerability than CVE-2014-6493, CVE-2014-6503, and CVE-2014-6532. (bnc#901239
  901242 901246)
- CVE-2014-6493: Unspecified vulnerability in Oracle Java SE 6u81, 7u67, and
  8u20 allows remote attackers to affect confidentiality, integrity, and
  availability via unknown vectors related to Deployment, a different
  vulnerability than CVE-2014-4288, CVE-2014-6503, and CVE-2014-6532. (bnc#901239
  901242 901246)
- CVE-2014-6492: Unspecified vulnerability in Oracle Java SE 6u81, 7u67, and
  8u20, when running on Firefox, allows remote attackers to affect
  confidentiality, integrity, and availability via unknown vectors related to
  Deployment. (bnc#901239 901242 901246)
- CVE-2014-6458: Unspecified vulnerability in Oracle Java SE 6u81, 7u67, and
  8u20 allows local users to affect confidentiality, integrity, and
  availability via unknown vectors related to Deployment. (bnc#901239 901242
  901246)
- CVE-2014-6466: Unspecified vulnerability in Oracle Java SE 6u81, 7u67, and
  8u20, when running on Internet Explorer, allows local users to affect
  confidentiality, integrity, and availability via unknown vectors related to
  Deployment. (bnc#901239 901242 901246)
- CVE-2014-6506: Unspecified vulnerability in Oracle Java SE 5.0u71, 6u81,
  7u67, and 8u20, and Java SE Embedded 7u60, allows remote attackers to affect
  confidentiality, integrity, and availability via unknown vectors related to
  Libraries. (bnc#901239 901242 901246)
- CVE-2014-6476: Unspecified vulnerability in Oracle Java SE 7u67 and 8u20
  allows remote attackers to affect integrity via unknown vectors related to
  Deployment, a different vulnerability than CVE-2014-6527. (bnc#901239 901242
  901246)
- CVE-2014-6515: Unspecified vulnerability in Oracle Java SE 6u81, 7u67, and
  8u20 allows remote attackers to affect integrity via unknown vectors related
  to Deployment. (bnc#901239 901242 901246)
- CVE-2014-6511: Unspecified vulnerability in Oracle Java SE 5.0u71, 6u81,
  7u67, and 8u20 allows remote attackers to affect confidentiality via unknown
  vectors related to 2D. (bnc#901239 901242 901246)
- CVE-2014-6531: Unspecified vulnerability in Oracle Java SE 5.0u71, 6u81,
  7u67, and 8u20, and Java SE Embedded 7u60, allows remote attackers to affect
  confidentiality via unknown vectors related to Libraries. (bnc#901239 901242
  901246)
- CVE-2014-6512: Unspecified vulnerability in Oracle Java SE 5.0u71, 6u81,
  7u67, and 8u20; Java SE Embedded 7u60; and JRockit R27.8.3 and R28.3.3 allows
  remote attackers to affect integrity via unknown vectors related to Libraries.
  (bnc#901239 901242 901246)
- CVE-2014-6457: Unspecified vulnerability in Oracle Java SE 5.0u71, 6u81,
  7u67, and 8u20; Java SE Embedded 7u60; and JRockit R27.8.3, and R28.3.3
  allows remote attackers to affect confidentiality and integrity via vectors
  related to JSSE. (bnc#901239 901242 901246)
- CVE-2014-6527: Unspecified vulnerability in Oracle Java SE 7u67 and 8u20
  allows remote attackers to affect integrity via unknown vectors related to
  Deployment, a different vulnerability than CVE-2014-6476. (bnc#901239 901242
  901246)
- CVE-2014-6502: Unspecified vulnerability in Oracle Java SE 5.0u71, 6u81,
  7u67, and 8u20, and Java SE Embedded 7u60, allows remote attackers to affect
  integrity via unknown vectors related to Libraries. (bnc#901239 901242 901246)
- CVE-2014-6558: Unspecified vulnerability in Oracle Java SE 5.0u71, 6u81,
  7u67, and 8u20; Java SE Embedded 7u60; and JRockit R27.8.3 and JRockit
  R28.3.3 allows remote attackers to affect integrity via unknown vectors related
  to Security. (bnc#901239 901242 901246)
* Fri Aug  8 2014 tchvatal@suse.com
- Version bump to 7.1-1.0 bnc#890434:
  * Maintenance update for the 7.1 series  matching oracle jaca 7u65
* Thu Aug  7 2014 tchvatal@suse.com
- Replace SuSE with SUSE. bnc#889006
* Wed May 14 2014 tchvatal@suse.com
- Version bump to 7.1-1.0 (bnc#877465):
  * support for ppc64le
  * zEC12 and System z hardware compression acceleration support
  * Improved workload management facilities on z/OS
  * Native record processing with Data Access Accelerator
  * see http://www-01.ibm.com/support/docview.wss?uid=swg21657707
* Wed Mar  5 2014 ro@suse.de
- Fix build on i586 and s390
  * Remove bogus dependency on libstdc++33
* Mon Feb 17 2014 mvyskocil@suse.com
- Limit package to sle12 compatible architectures
- Use SUSE-NonFree License as suggested by legal team
- Adapt filelist to much stricter rpm in SLE12
* Tue Dec 10 2013 mvyskocil@suse.com
- package IBM Java Version 7 Release 1 (FATE#316606)
  IBM(R) SDK, Java Technology Edition, Version 7 Release 1 is the latest
  release of the Java SE 7 application programming interfaces (APIs). This
  release contains the latest virtual machine technology from IBM and is for
  users who wish to use Java SE 7 APIs to:
  * utilize enhanced native record processing
  * exploit the new zEC12 capabilities
  * improve monitoring and diagnostics
  * evaluate IBM's latest cloud enablement technology
  * see http://www-01.ibm.com/support/docview.wss?uid=swg21657707
